"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import bilireq.grpc.protos.bilibili.app.archive.v1.archive_pb2
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BizType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _BizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BizTypeNone: _BizType.ValueType  # 0
    """"""

    BizTypeFollowVideo: _BizType.ValueType  # 1
    """追番追剧"""

    BizTypeReserveActivity: _BizType.ValueType  # 2
    """预约活动"""

    BizTypeJumpLink: _BizType.ValueType  # 3
    """跳转链接"""

    BizTypeFavSeason: _BizType.ValueType  # 4
    """收藏合集"""

    BizTypeReserveGame: _BizType.ValueType  # 5
    """预约游戏"""

class BizType(_BizType, metaclass=_BizTypeEnumTypeWrapper):
    """业务类型"""
    pass

BizTypeNone: BizType.ValueType  # 0
""""""

BizTypeFollowVideo: BizType.ValueType  # 1
"""追番追剧"""

BizTypeReserveActivity: BizType.ValueType  # 2
"""预约活动"""

BizTypeJumpLink: BizType.ValueType  # 3
"""跳转链接"""

BizTypeFavSeason: BizType.ValueType  # 4
"""收藏合集"""

BizTypeReserveGame: BizType.ValueType  # 5
"""预约游戏"""

global___BizType = BizType


class _DescType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _DescTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DescType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DescTypeUnknown: _DescType.ValueType  # 0
    """占位"""

    DescTypeText: _DescType.ValueType  # 1
    """文本"""

    DescTypeAt: _DescType.ValueType  # 2
    """@"""

class DescType(_DescType, metaclass=_DescTypeEnumTypeWrapper):
    """枚举-文本类型"""
    pass

DescTypeUnknown: DescType.ValueType  # 0
"""占位"""

DescTypeText: DescType.ValueType  # 1
"""文本"""

DescTypeAt: DescType.ValueType  # 2
"""@"""

global___DescType = DescType


class _ECode:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ECodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ECode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _ECode.ValueType  # 0
    """正常"""

    CODE404: _ECode.ValueType  # 1
    """稿件被UP主删除"""

class ECode(_ECode, metaclass=_ECodeEnumTypeWrapper):
    """错误代码"""
    pass

DEFAULT: ECode.ValueType  # 0
"""正常"""

CODE404: ECode.ValueType  # 1
"""稿件被UP主删除"""

global___ECode = ECode


class _MaterialSource:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _MaterialSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaterialSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Default: _MaterialSource.ValueType  # 0
    BiJian: _MaterialSource.ValueType  # 1
class MaterialSource(_MaterialSource, metaclass=_MaterialSourceEnumTypeWrapper):
    """"""
    pass

Default: MaterialSource.ValueType  # 0
BiJian: MaterialSource.ValueType  # 1
global___MaterialSource = MaterialSource


class _OperationCardType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _OperationCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OperationCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CardTypeNone: _OperationCardType.ValueType  # 0
    """"""

    CardTypeStandard: _OperationCardType.ValueType  # 1
    """标准卡"""

    CardTypeSkip: _OperationCardType.ValueType  # 2
    """原跳转卡"""

class OperationCardType(_OperationCardType, metaclass=_OperationCardTypeEnumTypeWrapper):
    """卡片样式"""
    pass

CardTypeNone: OperationCardType.ValueType  # 0
""""""

CardTypeStandard: OperationCardType.ValueType  # 1
"""标准卡"""

CardTypeSkip: OperationCardType.ValueType  # 2
"""原跳转卡"""

global___OperationCardType = OperationCardType


class _PlayerCardType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PlayerCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayerCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PlayerCardTypeNone_VALUE: _PlayerCardType.ValueType  # 0
    """"""

    PlayerCardTypeAttention_VALUE: _PlayerCardType.ValueType  # 1
    """关注卡"""

    PlayerCardTypeOperation_VALUE: _PlayerCardType.ValueType  # 2
    """运营卡"""

    PlayerCardTypeContract_VALUE: _PlayerCardType.ValueType  # 3
    """契约卡"""

class PlayerCardType(_PlayerCardType, metaclass=_PlayerCardTypeEnumTypeWrapper):
    """卡片类型"""
    pass

PlayerCardTypeNone_VALUE: PlayerCardType.ValueType  # 0
""""""

PlayerCardTypeAttention_VALUE: PlayerCardType.ValueType  # 1
"""关注卡"""

PlayerCardTypeOperation_VALUE: PlayerCardType.ValueType  # 2
"""运营卡"""

PlayerCardTypeContract_VALUE: PlayerCardType.ValueType  # 3
"""契约卡"""

global___PlayerCardType = PlayerCardType


class _SeasonType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _SeasonTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SeasonType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _SeasonType.ValueType  # 0
    """"""

    Base: _SeasonType.ValueType  # 1
    """"""

    Good: _SeasonType.ValueType  # 2
    """"""

class SeasonType(_SeasonType, metaclass=_SeasonTypeEnumTypeWrapper):
    """"""
    pass

Unknown: SeasonType.ValueType  # 0
""""""

Base: SeasonType.ValueType  # 1
""""""

Good: SeasonType.ValueType  # 2
""""""

global___SeasonType = SeasonType


class _TabOtype:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TabOtypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabOtype.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownOtype: _TabOtype.ValueType  # 0
    """未知类型"""

    URL: _TabOtype.ValueType  # 1
    """url链接"""

    TopicNA: _TabOtype.ValueType  # 2
    """native话题活动"""

class TabOtype(_TabOtype, metaclass=_TabOtypeEnumTypeWrapper):
    """TAB跳转类型"""
    pass

UnknownOtype: TabOtype.ValueType  # 0
"""未知类型"""

URL: TabOtype.ValueType  # 1
"""url链接"""

TopicNA: TabOtype.ValueType  # 2
"""native话题活动"""

global___TabOtype = TabOtype


class _TabStyle:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _TabStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TabStyle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UnknownStyle: _TabStyle.ValueType  # 0
    """未知样式"""

    Text: _TabStyle.ValueType  # 1
    """文字样式"""

    Pic: _TabStyle.ValueType  # 2
    """图片样式"""

class TabStyle(_TabStyle, metaclass=_TabStyleEnumTypeWrapper):
    """TAB样式"""
    pass

UnknownStyle: TabStyle.ValueType  # 0
"""未知样式"""

Text: TabStyle.ValueType  # 1
"""文字样式"""

Pic: TabStyle.ValueType  # 2
"""图片样式"""

global___TabStyle = TabStyle


class ActivityResource(google.protobuf.message.Message):
    """活动页资源包"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MOD_POOL_NAME_FIELD_NUMBER: builtins.int
    MOD_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    SELECTED_BG_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    LIGHT_TEXT_COLOR_FIELD_NUMBER: builtins.int
    DARK_TEXT_COLOR_FIELD_NUMBER: builtins.int
    DIVIDER_COLOR_FIELD_NUMBER: builtins.int
    mod_pool_name: typing.Text
    """mod资源池名称"""

    mod_resource_name: typing.Text
    """mod资源名称"""

    bg_color: typing.Text
    """背景色"""

    selected_bg_color: typing.Text
    """选中背景色"""

    text_color: typing.Text
    """文字颜色"""

    light_text_color: typing.Text
    """浅字色"""

    dark_text_color: typing.Text
    """深字色"""

    divider_color: typing.Text
    """分割线色"""

    def __init__(self,
        *,
        mod_pool_name: typing.Text = ...,
        mod_resource_name: typing.Text = ...,
        bg_color: typing.Text = ...,
        selected_bg_color: typing.Text = ...,
        text_color: typing.Text = ...,
        light_text_color: typing.Text = ...,
        dark_text_color: typing.Text = ...,
        divider_color: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","dark_text_color",b"dark_text_color","divider_color",b"divider_color","light_text_color",b"light_text_color","mod_pool_name",b"mod_pool_name","mod_resource_name",b"mod_resource_name","selected_bg_color",b"selected_bg_color","text_color",b"text_color"]) -> None: ...
global___ActivityResource = ActivityResource

class ActivitySeason(google.protobuf.message.Message):
    """大型活动合集"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    HONOR_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    SUPPORT_DISLIKE_FIELD_NUMBER: builtins.int
    OPERATION_RELATE_FIELD_NUMBER: builtins.int
    ACTIVITY_RESOURCE_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    CM_CONFIG_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    ECODE_FIELD_NUMBER: builtins.int
    CUSTOM_CONFIG_FIELD_NUMBER: builtins.int
    BADGE_URL_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilibili.app.archive.v1.archive_pb2.Arc:
        """稿件信息"""
        pass
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """分P信息"""
        pass
    @property
    def owner_ext(self) -> global___OnwerExt:
        """("OnwerExt"为源码中拼写错误)"""
        pass
    @property
    def req_user(self) -> global___ReqUser:
        """稿件用户操作状态"""
        pass
    @property
    def elec_rank(self) -> global___ElecRank:
        """充电排行"""
        pass
    @property
    def history(self) -> global___History:
        """历史观看进度"""
        pass
    bvid: typing.Text
    """稿件bvid"""

    @property
    def honor(self) -> global___Honor:
        """获得荣誉信息"""
        pass
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """联合投稿成员列表"""
        pass
    @property
    def ugc_season(self) -> global___UgcSeason:
        """UGC视频合集信息"""
        pass
    @property
    def tab(self) -> global___Tab:
        """播放页定制tab"""
        pass
    @property
    def rank(self) -> global___Rank:
        """排行榜"""
        pass
    @property
    def order(self) -> global___Order:
        """预约模块"""
        pass
    support_dislike: builtins.bool
    """是否支持点踩"""

    @property
    def operation_relate(self) -> global___OperationRelate:
        """相关推荐(运营配置+AI推荐)"""
        pass
    @property
    def activity_resource(self) -> global___ActivityResource:
        """活动页资源包"""
        pass
    short_link: typing.Text
    """短链接"""

    @property
    def label(self) -> global___Label:
        """标签"""
        pass
    @property
    def dislike(self) -> global___Dislike:
        """不感兴趣原因"""
        pass
    @property
    def player_icon(self) -> global___PlayerIcon:
        """播放图标动画配置档"""
        pass
    share_subtitle: typing.Text
    """分享副标题(已观看xxx次)"""

    @property
    def cm_config(self) -> global___CMConfig:
        """广告配置"""
        pass
    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """免流面板定制"""
        pass
    argue_msg: typing.Text
    """争议信息"""

    ecode: global___ECode.ValueType
    """错误码
    DEFAULT:正常 CODE404:视频被UP主删除
    """

    @property
    def custom_config(self) -> global___CustomConfig:
        """404页信息"""
        pass
    badge_url: typing.Text
    """评论样式"""

    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """稿件简介v2"""
        pass
    @property
    def config(self) -> global___Config:
        """"""
        pass
    @property
    def online(self) -> global___Online:
        """"""
        pass
    def __init__(self,
        *,
        arc: typing.Optional[bilibili.app.archive.v1.archive_pb2.Arc] = ...,
        pages: typing.Optional[typing.Iterable[global___ViewPage]] = ...,
        owner_ext: typing.Optional[global___OnwerExt] = ...,
        req_user: typing.Optional[global___ReqUser] = ...,
        elec_rank: typing.Optional[global___ElecRank] = ...,
        history: typing.Optional[global___History] = ...,
        bvid: typing.Text = ...,
        honor: typing.Optional[global___Honor] = ...,
        staff: typing.Optional[typing.Iterable[global___Staff]] = ...,
        ugc_season: typing.Optional[global___UgcSeason] = ...,
        tab: typing.Optional[global___Tab] = ...,
        rank: typing.Optional[global___Rank] = ...,
        order: typing.Optional[global___Order] = ...,
        support_dislike: builtins.bool = ...,
        operation_relate: typing.Optional[global___OperationRelate] = ...,
        activity_resource: typing.Optional[global___ActivityResource] = ...,
        short_link: typing.Text = ...,
        label: typing.Optional[global___Label] = ...,
        dislike: typing.Optional[global___Dislike] = ...,
        player_icon: typing.Optional[global___PlayerIcon] = ...,
        share_subtitle: typing.Text = ...,
        cm_config: typing.Optional[global___CMConfig] = ...,
        tf_panel_customized: typing.Optional[global___TFPanelCustomized] = ...,
        argue_msg: typing.Text = ...,
        ecode: global___ECode.ValueType = ...,
        custom_config: typing.Optional[global___CustomConfig] = ...,
        badge_url: typing.Text = ...,
        desc_v2: typing.Optional[typing.Iterable[global___DescV2]] = ...,
        config: typing.Optional[global___Config] = ...,
        online: typing.Optional[global___Online] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity_resource",b"activity_resource","arc",b"arc","cm_config",b"cm_config","config",b"config","custom_config",b"custom_config","dislike",b"dislike","elec_rank",b"elec_rank","history",b"history","honor",b"honor","label",b"label","online",b"online","operation_relate",b"operation_relate","order",b"order","owner_ext",b"owner_ext","player_icon",b"player_icon","rank",b"rank","req_user",b"req_user","tab",b"tab","tf_panel_customized",b"tf_panel_customized","ugc_season",b"ugc_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_resource",b"activity_resource","arc",b"arc","argue_msg",b"argue_msg","badge_url",b"badge_url","bvid",b"bvid","cm_config",b"cm_config","config",b"config","custom_config",b"custom_config","desc_v2",b"desc_v2","dislike",b"dislike","ecode",b"ecode","elec_rank",b"elec_rank","history",b"history","honor",b"honor","label",b"label","online",b"online","operation_relate",b"operation_relate","order",b"order","owner_ext",b"owner_ext","pages",b"pages","player_icon",b"player_icon","rank",b"rank","req_user",b"req_user","share_subtitle",b"share_subtitle","short_link",b"short_link","staff",b"staff","support_dislike",b"support_dislike","tab",b"tab","tf_panel_customized",b"tf_panel_customized","ugc_season",b"ugc_season"]) -> None: ...
global___ActivitySeason = ActivitySeason

class AdInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CREATIVE_ID_FIELD_NUMBER: builtins.int
    CREATIVE_TYPE_FIELD_NUMBER: builtins.int
    CREATIVE_CONTENT_FIELD_NUMBER: builtins.int
    AD_CB_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    creative_id: builtins.int
    """"""

    creative_type: builtins.int
    """"""

    @property
    def creative_content(self) -> global___CreativeContent:
        """"""
        pass
    ad_cb: typing.Text
    """"""

    card_type: builtins.int
    """"""

    def __init__(self,
        *,
        creative_id: builtins.int = ...,
        creative_type: builtins.int = ...,
        creative_content: typing.Optional[global___CreativeContent] = ...,
        ad_cb: typing.Text = ...,
        card_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creative_content",b"creative_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_cb",b"ad_cb","card_type",b"card_type","creative_content",b"creative_content","creative_id",b"creative_id","creative_type",b"creative_type"]) -> None: ...
global___AdInfo = AdInfo

class AddContractReq(google.protobuf.message.Message):
    """点击签订契约-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    up_mid: builtins.int
    """UP主mid"""

    spmid: typing.Text
    """当前页面spm"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        up_mid: builtins.int = ...,
        spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","spmid",b"spmid","up_mid",b"up_mid"]) -> None: ...
global___AddContractReq = AddContractReq

class Asset(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAID_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    PREVIEW_MSG_FIELD_NUMBER: builtins.int
    paid: builtins.int
    """"""

    price: builtins.int
    """"""

    @property
    def msg(self) -> global___AssetMsg:
        """"""
        pass
    @property
    def preview_msg(self) -> global___AssetMsg:
        """"""
        pass
    def __init__(self,
        *,
        paid: builtins.int = ...,
        price: builtins.int = ...,
        msg: typing.Optional[global___AssetMsg] = ...,
        preview_msg: typing.Optional[global___AssetMsg] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["msg",b"msg","preview_msg",b"preview_msg"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg","paid",b"paid","preview_msg",b"preview_msg","price",b"price"]) -> None: ...
global___Asset = Asset

class AssetMsg(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESC1_FIELD_NUMBER: builtins.int
    DESC2_FIELD_NUMBER: builtins.int
    desc1: typing.Text
    """"""

    desc2: typing.Text
    """"""

    def __init__(self,
        *,
        desc1: typing.Text = ...,
        desc2: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc1",b"desc1","desc2",b"desc2"]) -> None: ...
global___AssetMsg = AssetMsg

class Attention(google.protobuf.message.Message):
    """关注按钮卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    POS_X_FIELD_NUMBER: builtins.int
    POS_Y_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """开始时间"""

    end_time: builtins.int
    """结束时间"""

    pos_x: builtins.float
    """位置x坐标"""

    pos_y: builtins.float
    """位置y坐标"""

    def __init__(self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        pos_x: builtins.float = ...,
        pos_y: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time",b"end_time","pos_x",b"pos_x","pos_y",b"pos_y","start_time",b"start_time"]) -> None: ...
global___Attention = Attention

class Audio(google.protobuf.message.Message):
    """音频稿件信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    COVER_URL_FIELD_NUMBER: builtins.int
    SONG_ID_FIELD_NUMBER: builtins.int
    PLAY_COUNT_FIELD_NUMBER: builtins.int
    REPLY_COUNT_FIELD_NUMBER: builtins.int
    UPPER_ID_FIELD_NUMBER: builtins.int
    ENTRANCE_FIELD_NUMBER: builtins.int
    SONG_ATTR_FIELD_NUMBER: builtins.int
    title: typing.Text
    """音频标题"""

    cover_url: typing.Text
    """音频封面url"""

    song_id: builtins.int
    """音频auid"""

    play_count: builtins.int
    """音频播放量"""

    reply_count: builtins.int
    """音频评论数"""

    upper_id: builtins.int
    """音频作者UID"""

    entrance: typing.Text
    """进入按钮文案"""

    song_attr: builtins.int
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        cover_url: typing.Text = ...,
        song_id: builtins.int = ...,
        play_count: builtins.int = ...,
        reply_count: builtins.int = ...,
        upper_id: builtins.int = ...,
        entrance: typing.Text = ...,
        song_attr: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover_url",b"cover_url","entrance",b"entrance","play_count",b"play_count","reply_count",b"reply_count","song_attr",b"song_attr","song_id",b"song_id","title",b"title","upper_id",b"upper_id"]) -> None: ...
global___Audio = Audio

class Bgm(google.protobuf.message.Message):
    """视频引用的bgm音频"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    JUMPURL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """音频auid"""

    mid: builtins.int
    """音频作者mid"""

    title: typing.Text
    """音频标题"""

    author: typing.Text
    """音频作者昵称"""

    jumpUrl: typing.Text
    """bgm页面url"""

    cover: typing.Text
    """音频封面url"""

    def __init__(self,
        *,
        sid: builtins.int = ...,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        author: typing.Text = ...,
        jumpUrl: typing.Text = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author",b"author","cover",b"cover","jumpUrl",b"jumpUrl","mid",b"mid","sid",b"sid","title",b"title"]) -> None: ...
global___Bgm = Bgm

class BizFavSeasonParam(google.protobuf.message.Message):
    """收藏合集参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id",b"season_id"]) -> None: ...
global___BizFavSeasonParam = BizFavSeasonParam

class BizFollowVideoParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id",b"season_id"]) -> None: ...
global___BizFollowVideoParam = BizFollowVideoParam

class BizJumpLinkParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    url: typing.Text
    """链接"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url",b"url"]) -> None: ...
global___BizJumpLinkParam = BizJumpLinkParam

class BizReserveActivityParam(google.protobuf.message.Message):
    """预约活动参数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""

    type: typing.Text
    """类型"""

    oid: builtins.int
    """资源id"""

    reserve_id: builtins.int
    """"""

    def __init__(self,
        *,
        activity_id: builtins.int = ...,
        type: typing.Text = ...,
        oid: builtins.int = ...,
        reserve_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id",b"activity_id","from",b"from","oid",b"oid","reserve_id",b"reserve_id","type",b"type"]) -> None: ...
global___BizReserveActivityParam = BizReserveActivityParam

class BizReserveGameParam(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GAME_ID_FIELD_NUMBER: builtins.int
    game_id: builtins.int
    """游戏id"""

    def __init__(self,
        *,
        game_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["game_id",b"game_id"]) -> None: ...
global___BizReserveGameParam = BizReserveGameParam

class Button(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: typing.Text
    """按钮文案"""

    uri: typing.Text
    """跳转uri"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title",b"title","uri",b"uri"]) -> None: ...
global___Button = Button

class BuzzwordConfig(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    FOLLOW_CONTROL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BUZZWORD_ID_FIELD_NUMBER: builtins.int
    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    schema: typing.Text
    """"""

    source: builtins.int
    """"""

    start: builtins.int
    """"""

    end: builtins.int
    """"""

    follow_control: builtins.bool
    """"""

    id: builtins.int
    """"""

    buzzword_id: builtins.int
    """"""

    schema_type: builtins.int
    """"""

    picture: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        schema: typing.Text = ...,
        source: builtins.int = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        follow_control: builtins.bool = ...,
        id: builtins.int = ...,
        buzzword_id: builtins.int = ...,
        schema_type: builtins.int = ...,
        picture: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buzzword_id",b"buzzword_id","end",b"end","follow_control",b"follow_control","id",b"id","name",b"name","picture",b"picture","schema",b"schema","schema_type",b"schema_type","source",b"source","start",b"start"]) -> None: ...
global___BuzzwordConfig = BuzzwordConfig

class CM(google.protobuf.message.Message):
    """广告"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告数据(需解包)"""
        pass
    def __init__(self,
        *,
        source_content: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_content",b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_content",b"source_content"]) -> None: ...
global___CM = CM

class CMConfig(google.protobuf.message.Message):
    """广告配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADS_CONTROL_FIELD_NUMBER: builtins.int
    @property
    def ads_control(self) -> google.protobuf.any_pb2.Any:
        """广告配置数据(需要二次解包)"""
        pass
    def __init__(self,
        *,
        ads_control: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ads_control",b"ads_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ads_control",b"ads_control"]) -> None: ...
global___CMConfig = CMConfig

class CacheViewReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilibili.app.archive.v1.archive_pb2.Arc:
        """"""
        pass
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """"""
        pass
    @property
    def owner_ext(self) -> global___OnwerExt:
        """"""
        pass
    @property
    def req_user(self) -> global___ReqUser:
        """"""
        pass
    @property
    def season(self) -> global___Season:
        """"""
        pass
    @property
    def elec_rank(self) -> global___ElecRank:
        """"""
        pass
    @property
    def history(self) -> global___History:
        """"""
        pass
    @property
    def dislike(self) -> global___Dislike:
        """"""
        pass
    @property
    def player_icon(self) -> global___PlayerIcon:
        """"""
        pass
    bvid: typing.Text
    """"""

    short_link: typing.Text
    """"""

    share_subtitle: typing.Text
    """"""

    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """"""
        pass
    @property
    def online(self) -> global___Online:
        """"""
        pass
    def __init__(self,
        *,
        arc: typing.Optional[bilibili.app.archive.v1.archive_pb2.Arc] = ...,
        pages: typing.Optional[typing.Iterable[global___ViewPage]] = ...,
        owner_ext: typing.Optional[global___OnwerExt] = ...,
        req_user: typing.Optional[global___ReqUser] = ...,
        season: typing.Optional[global___Season] = ...,
        elec_rank: typing.Optional[global___ElecRank] = ...,
        history: typing.Optional[global___History] = ...,
        dislike: typing.Optional[global___Dislike] = ...,
        player_icon: typing.Optional[global___PlayerIcon] = ...,
        bvid: typing.Text = ...,
        short_link: typing.Text = ...,
        share_subtitle: typing.Text = ...,
        tf_panel_customized: typing.Optional[global___TFPanelCustomized] = ...,
        online: typing.Optional[global___Online] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc",b"arc","dislike",b"dislike","elec_rank",b"elec_rank","history",b"history","online",b"online","owner_ext",b"owner_ext","player_icon",b"player_icon","req_user",b"req_user","season",b"season","tf_panel_customized",b"tf_panel_customized"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc",b"arc","bvid",b"bvid","dislike",b"dislike","elec_rank",b"elec_rank","history",b"history","online",b"online","owner_ext",b"owner_ext","pages",b"pages","player_icon",b"player_icon","req_user",b"req_user","season",b"season","share_subtitle",b"share_subtitle","short_link",b"short_link","tf_panel_customized",b"tf_panel_customized"]) -> None: ...
global___CacheViewReply = CacheViewReply

class CacheViewReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    trackid: typing.Text
    """"""

    ad_extra: typing.Text
    """"""

    spmid: typing.Text
    """"""

    from_spmid: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        trackid: typing.Text = ...,
        ad_extra: typing.Text = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra",b"ad_extra","aid",b"aid","bvid",b"bvid","from",b"from","from_spmid",b"from_spmid","spmid",b"spmid","trackid",b"trackid"]) -> None: ...
global___CacheViewReq = CacheViewReq

class Chronos(google.protobuf.message.Message):
    """Chronos灰度管理"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MD5_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    md5: typing.Text
    """资源包md5"""

    file: typing.Text
    """资源包"""

    sign: typing.Text
    """"""

    def __init__(self,
        *,
        md5: typing.Text = ...,
        file: typing.Text = ...,
        sign: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file",b"file","md5",b"md5","sign",b"sign"]) -> None: ...
global___Chronos = Chronos

class ChronosPkgReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    service_key: typing.Text
    """"""

    engine_version: typing.Text
    """"""

    message_protocol: typing.Text
    """"""

    def __init__(self,
        *,
        service_key: typing.Text = ...,
        engine_version: typing.Text = ...,
        message_protocol: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["engine_version",b"engine_version","message_protocol",b"message_protocol","service_key",b"service_key"]) -> None: ...
global___ChronosPkgReq = ChronosPkgReq

class ClickActivitySeasonReq(google.protobuf.message.Message):
    """点击大型活动页预约-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    order_type: global___BizType.ValueType
    """预约类型"""

    spmid: typing.Text
    """当前页面spm"""

    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
        pass
    @property
    def fav_season(self) -> global___BizFavSeasonParam:
        """收藏合集参数"""
        pass
    action: builtins.int
    """操作
    0:操作 1:取消操作
    """

    def __init__(self,
        *,
        order_type: global___BizType.ValueType = ...,
        spmid: typing.Text = ...,
        reserve: typing.Optional[global___BizReserveActivityParam] = ...,
        fav_season: typing.Optional[global___BizFavSeasonParam] = ...,
        action: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season",b"fav_season","order_param",b"order_param","reserve",b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","fav_season",b"fav_season","order_param",b"order_param","order_type",b"order_type","reserve",b"reserve","spmid",b"spmid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["order_param",b"order_param"]) -> typing.Optional[typing_extensions.Literal["reserve","fav_season"]]: ...
global___ClickActivitySeasonReq = ClickActivitySeasonReq

class ClickPlayerCardReq(google.protobuf.message.Message):
    """点击播放器卡片-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片id"""

    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    action: builtins.int
    """操作
    0:操作 1:取消操作
    """

    spmid: typing.Text
    """当前页面spm"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        action: builtins.int = ...,
        spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","aid",b"aid","cid",b"cid","id",b"id","spmid",b"spmid"]) -> None: ...
global___ClickPlayerCardReq = ClickPlayerCardReq

class CmIpad(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CM_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    @property
    def cm(self) -> global___CM:
        """"""
        pass
    @property
    def author(self) -> bilibili.app.archive.v1.archive_pb2.Author:
        """"""
        pass
    @property
    def stat(self) -> bilibili.app.archive.v1.archive_pb2.Stat:
        """"""
        pass
    duration: builtins.int
    """"""

    aid: builtins.int
    """"""

    def __init__(self,
        *,
        cm: typing.Optional[global___CM] = ...,
        author: typing.Optional[bilibili.app.archive.v1.archive_pb2.Author] = ...,
        stat: typing.Optional[bilibili.app.archive.v1.archive_pb2.Stat] = ...,
        duration: builtins.int = ...,
        aid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","cm",b"cm","stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author",b"author","cm",b"cm","duration",b"duration","stat",b"stat"]) -> None: ...
global___CmIpad = CmIpad

class CommandDm(google.protobuf.message.Message):
    """互动弹幕条目信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""

    oid: builtins.int
    """对象视频cid"""

    mid: typing.Text
    """发送者mid"""

    command: typing.Text
    """互动弹幕指令"""

    content: typing.Text
    """互动弹幕正文"""

    progress: builtins.int
    """出现时间"""

    ctime: typing.Text
    """创建时间"""

    mtime: typing.Text
    """发布时间"""

    extra: typing.Text
    """扩展json数据"""

    idStr: typing.Text
    """弹幕id str类型"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: typing.Text = ...,
        command: typing.Text = ...,
        content: typing.Text = ...,
        progress: builtins.int = ...,
        ctime: typing.Text = ...,
        mtime: typing.Text = ...,
        extra: typing.Text = ...,
        idStr: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","content",b"content","ctime",b"ctime","extra",b"extra","id",b"id","idStr",b"idStr","mid",b"mid","mtime",b"mtime","oid",b"oid","progress",b"progress"]) -> None: ...
global___CommandDm = CommandDm

class Config(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RELATES_TITLE_FIELD_NUMBER: builtins.int
    RELATES_STYLE_FIELD_NUMBER: builtins.int
    RELATE_GIF_EXP_FIELD_NUMBER: builtins.int
    END_PAGE_HALF_FIELD_NUMBER: builtins.int
    END_PAGE_FULL_FIELD_NUMBER: builtins.int
    AUTO_SWINDOW_FIELD_NUMBER: builtins.int
    POPUP_INFO_FIELD_NUMBER: builtins.int
    ABTEST_SMALL_WINDOW_FIELD_NUMBER: builtins.int
    REC_THREE_POINT_STYLE_FIELD_NUMBER: builtins.int
    IS_ABSOLUTE_TIME_FIELD_NUMBER: builtins.int
    relates_title: typing.Text
    """下方推荐项标题"""

    relates_style: builtins.int
    """"""

    relate_gif_exp: builtins.int
    """"""

    end_page_half: builtins.int
    """"""

    end_page_full: builtins.int
    """"""

    auto_swindow: builtins.bool
    """退出是否自动小窗"""

    popup_info: builtins.bool
    """"""

    abtest_small_window: typing.Text
    """"""

    rec_three_point_style: builtins.int
    """"""

    is_absolute_time: builtins.bool
    """"""

    def __init__(self,
        *,
        relates_title: typing.Text = ...,
        relates_style: builtins.int = ...,
        relate_gif_exp: builtins.int = ...,
        end_page_half: builtins.int = ...,
        end_page_full: builtins.int = ...,
        auto_swindow: builtins.bool = ...,
        popup_info: builtins.bool = ...,
        abtest_small_window: typing.Text = ...,
        rec_three_point_style: builtins.int = ...,
        is_absolute_time: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["abtest_small_window",b"abtest_small_window","auto_swindow",b"auto_swindow","end_page_full",b"end_page_full","end_page_half",b"end_page_half","is_absolute_time",b"is_absolute_time","popup_info",b"popup_info","rec_three_point_style",b"rec_three_point_style","relate_gif_exp",b"relate_gif_exp","relates_style",b"relates_style","relates_title",b"relates_title"]) -> None: ...
global___Config = Config

class ContractCard(google.protobuf.message.Message):
    """契约卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISPLAY_PROGRESS_FIELD_NUMBER: builtins.int
    DISPLAY_ACCURACY_FIELD_NUMBER: builtins.int
    DISPLAY_DURATION_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    PAGE_TYPE_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    IS_FOLLOW_DISPLAY_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    FOLLOW_DISPLAY_END_DURATION_FIELD_NUMBER: builtins.int
    IS_PLAY_DISPLAY_FIELD_NUMBER: builtins.int
    display_progress: builtins.float
    """需要触发的播放进度百分比"""

    display_accuracy: builtins.int
    """触发位置的前后误差(单位ms)"""

    display_duration: builtins.int
    """展示持续时间(单位ms)"""

    show_mode: builtins.int
    """弹出模式
    0: 原有模式 1: 半屏弹出 2: 全屏、半屏均弹出
    """

    page_type: builtins.int
    """提示页面
    0: 原有页面 1: 6.23版本新页面
    """

    @property
    def upper(self) -> global___UpperInfos:
        """UP主信息"""
        pass
    is_follow_display: builtins.int
    """"""

    @property
    def text(self) -> global___ContractText:
        """"""
        pass
    follow_display_end_duration: builtins.int
    """"""

    is_play_display: builtins.int
    """"""

    def __init__(self,
        *,
        display_progress: builtins.float = ...,
        display_accuracy: builtins.int = ...,
        display_duration: builtins.int = ...,
        show_mode: builtins.int = ...,
        page_type: builtins.int = ...,
        upper: typing.Optional[global___UpperInfos] = ...,
        is_follow_display: builtins.int = ...,
        text: typing.Optional[global___ContractText] = ...,
        follow_display_end_duration: builtins.int = ...,
        is_play_display: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["text",b"text","upper",b"upper"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_accuracy",b"display_accuracy","display_duration",b"display_duration","display_progress",b"display_progress","follow_display_end_duration",b"follow_display_end_duration","is_follow_display",b"is_follow_display","is_play_display",b"is_play_display","page_type",b"page_type","show_mode",b"show_mode","text",b"text","upper",b"upper"]) -> None: ...
global___ContractCard = ContractCard

class ContractText(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    INLINE_TITLE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    subtitle: typing.Text
    """"""

    inline_title: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        subtitle: typing.Text = ...,
        inline_title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_title",b"inline_title","subtitle",b"subtitle","title",b"title"]) -> None: ...
global___ContractText = ContractText

class CreativeContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_MD5_FIELD_NUMBER: builtins.int
    LOG_URL_FIELD_NUMBER: builtins.int
    LOG_MD5_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    SHOW_URL_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    description: typing.Text
    """"""

    button_title: typing.Text
    """"""

    video_id: builtins.int
    """"""

    username: typing.Text
    """"""

    image_url: typing.Text
    """"""

    image_md5: typing.Text
    """"""

    log_url: typing.Text
    """"""

    log_md5: typing.Text
    """"""

    url: typing.Text
    """"""

    click_url: typing.Text
    """"""

    show_url: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        description: typing.Text = ...,
        button_title: typing.Text = ...,
        video_id: builtins.int = ...,
        username: typing.Text = ...,
        image_url: typing.Text = ...,
        image_md5: typing.Text = ...,
        log_url: typing.Text = ...,
        log_md5: typing.Text = ...,
        url: typing.Text = ...,
        click_url: typing.Text = ...,
        show_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_title",b"button_title","click_url",b"click_url","description",b"description","image_md5",b"image_md5","image_url",b"image_url","log_md5",b"log_md5","log_url",b"log_url","show_url",b"show_url","title",b"title","url",b"url","username",b"username","video_id",b"video_id"]) -> None: ...
global___CreativeContent = CreativeContent

class CustomConfig(google.protobuf.message.Message):
    """404页信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    redirect_url: typing.Text
    """重定向页面url"""

    def __init__(self,
        *,
        redirect_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["redirect_url",b"redirect_url"]) -> None: ...
global___CustomConfig = CustomConfig

class DM(google.protobuf.message.Message):
    """分P弹幕信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CLOSED_FIELD_NUMBER: builtins.int
    REAL_NAME_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """分P是否关闭弹幕
    0:正常 1:关闭
    """

    real_name: builtins.bool
    """"""

    count: builtins.int
    """分P弹幕总数"""

    def __init__(self,
        *,
        closed: builtins.bool = ...,
        real_name: builtins.bool = ...,
        count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed",b"closed","count",b"count","real_name",b"real_name"]) -> None: ...
global___DM = DM

class DescV2(google.protobuf.message.Message):
    """特殊稿件简介"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    text: typing.Text
    """文本内容"""

    type: global___DescType.ValueType
    """文本类型"""

    uri: typing.Text
    """点击跳转链接"""

    rid: builtins.int
    """资源ID"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        type: global___DescType.ValueType = ...,
        uri: typing.Text = ...,
        rid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rid",b"rid","text",b"text","type",b"type","uri",b"uri"]) -> None: ...
global___DescV2 = DescV2

class Dislike(google.protobuf.message.Message):
    """不喜欢原因"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    REASONS_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    subtitle: typing.Text
    """"""

    @property
    def reasons(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReasons]:
        """原因项列表"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        subtitle: typing.Text = ...,
        reasons: typing.Optional[typing.Iterable[global___DislikeReasons]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reasons",b"reasons","subtitle",b"subtitle","title",b"title"]) -> None: ...
global___Dislike = Dislike

class DislikeReasons(google.protobuf.message.Message):
    """不喜欢原因项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    TAG_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """类型
    1:全部类型 3:TAG 4:UP主
    """

    mid: builtins.int
    """相关UP主mid"""

    rid: builtins.int
    """相关分区tid"""

    tag_id: builtins.int
    """相关TAG id"""

    name: typing.Text
    """相关名称"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        mid: builtins.int = ...,
        rid: builtins.int = ...,
        tag_id: builtins.int = ...,
        name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","mid",b"mid","name",b"name","rid",b"rid","tag_id",b"tag_id"]) -> None: ...
global___DislikeReasons = DislikeReasons

class ElecRank(google.protobuf.message.Message):
    """充电排行信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ElecRankItem]:
        """充电排行列表"""
        pass
    count: builtins.int
    """充电用户数"""

    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___ElecRankItem]] = ...,
        count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count","list",b"list"]) -> None: ...
global___ElecRank = ElecRank

class ElecRankItem(google.protobuf.message.Message):
    """充电用户信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AVATAR_FIELD_NUMBER: builtins.int
    NICKNAME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    avatar: typing.Text
    """用户头像url"""

    nickname: typing.Text
    """用户昵称"""

    message: typing.Text
    """充电留言"""

    mid: builtins.int
    """用户mid"""

    def __init__(self,
        *,
        avatar: typing.Text = ...,
        nickname: typing.Text = ...,
        message: typing.Text = ...,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar",b"avatar","message",b"message","mid",b"mid","nickname",b"nickname"]) -> None: ...
global___ElecRankItem = ElecRankItem

class Episode(google.protobuf.message.Message):
    """视频合集单话信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    COVERRIGHTTEXT_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    AUTHOR_DESC_FIELD_NUMBER: builtins.int
    id: builtins.int
    """合集单话id"""

    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频1P cid"""

    title: typing.Text
    """稿件标题"""

    cover: typing.Text
    """稿件封面url"""

    coverRightText: typing.Text
    """投稿时间显示文案"""

    @property
    def page(self) -> bilibili.app.archive.v1.archive_pb2.Page:
        """视频分P信息"""
        pass
    @property
    def stat(self) -> bilibili.app.archive.v1.archive_pb2.Stat:
        """视频状态数"""
        pass
    bvid: typing.Text
    """稿件bvid"""

    @property
    def author(self) -> bilibili.app.archive.v1.archive_pb2.Author:
        """稿件UP主信息"""
        pass
    author_desc: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        coverRightText: typing.Text = ...,
        page: typing.Optional[bilibili.app.archive.v1.archive_pb2.Page] = ...,
        stat: typing.Optional[bilibili.app.archive.v1.archive_pb2.Stat] = ...,
        bvid: typing.Text = ...,
        author: typing.Optional[bilibili.app.archive.v1.archive_pb2.Author] = ...,
        author_desc: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","page",b"page","stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author",b"author","author_desc",b"author_desc","bvid",b"bvid","cid",b"cid","cover",b"cover","coverRightText",b"coverRightText","id",b"id","page",b"page","stat",b"stat","title",b"title"]) -> None: ...
global___Episode = Episode

class ExposePlayerCardReq(google.protobuf.message.Message):
    """播放器卡片曝光-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CARD_TYPE_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    card_type: global___PlayerCardType.ValueType
    """卡片类型"""

    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    spmid: typing.Text
    """当前页面spm"""

    def __init__(self,
        *,
        card_type: global___PlayerCardType.ValueType = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","card_type",b"card_type","cid",b"cid","spmid",b"spmid"]) -> None: ...
global___ExposePlayerCardReq = ExposePlayerCardReq

class FeedViewItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIEW_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    @property
    def view(self) -> global___ViewReply:
        """"""
        pass
    goto: typing.Text
    """"""

    uri: typing.Text
    """"""

    track_id: typing.Text
    """"""

    def __init__(self,
        *,
        view: typing.Optional[global___ViewReply] = ...,
        goto: typing.Text = ...,
        uri: typing.Text = ...,
        track_id: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["view",b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["goto",b"goto","track_id",b"track_id","uri",b"uri","view",b"view"]) -> None: ...
global___FeedViewItem = FeedViewItem

class FeedViewReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIST_FIELD_NUMBER: builtins.int
    HAS_NEXT_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeedViewItem]:
        """"""
        pass
    has_next: builtins.bool
    """"""

    def __init__(self,
        *,
        list: typing.Optional[typing.Iterable[global___FeedViewItem]] = ...,
        has_next: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_next",b"has_next","list",b"list"]) -> None: ...
global___FeedViewReply = FeedViewReply

class FeedViewReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    DISPLAY_ID_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    PAGE_VERSION_FIELD_NUMBER: builtins.int
    FROM_TRACK_ID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    bvid: typing.Text
    """"""

    spmid: typing.Text
    """"""

    from_spmid: typing.Text
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """"""
        pass
    display_id: builtins.int
    """"""

    session_id: typing.Text
    """"""

    page_version: typing.Text
    """"""

    from_track_id: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        display_id: builtins.int = ...,
        session_id: typing.Text = ...,
        page_version: typing.Text = ...,
        from_track_id: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","bvid",b"bvid","display_id",b"display_id","from",b"from","from_spmid",b"from_spmid","from_track_id",b"from_track_id","page_version",b"page_version","player_args",b"player_args","session_id",b"session_id","spmid",b"spmid"]) -> None: ...
global___FeedViewReq = FeedViewReq

class History(google.protobuf.message.Message):
    """稿件观看进度"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """播放进度分P cid"""

    progress: builtins.int
    """播放进度时间
    0:未观看 -1:已看完 正整数:播放时间进度
    """

    def __init__(self,
        *,
        cid: builtins.int = ...,
        progress: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","progress",b"progress"]) -> None: ...
global___History = History

class Honor(google.protobuf.message.Message):
    """稿件获得荣誉信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_EXTRA_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    URL_TEXT_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """荣誉栏图标url"""

    icon_night: typing.Text
    """荣誉栏图标url 夜间模式"""

    text: typing.Text
    """荣誉文案"""

    text_extra: typing.Text
    """荣誉副文案"""

    text_color: typing.Text
    """标题颜色"""

    text_color_night: typing.Text
    """标题颜色 夜间模式"""

    bg_color: typing.Text
    """背景颜色"""

    bg_color_night: typing.Text
    """背景颜色 夜间模式"""

    url: typing.Text
    """跳转uri"""

    url_text: typing.Text
    """跳转角标文案"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        icon_night: typing.Text = ...,
        text: typing.Text = ...,
        text_extra: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        url: typing.Text = ...,
        url_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","icon",b"icon","icon_night",b"icon_night","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night","text_extra",b"text_extra","url",b"url","url_text",b"url_text"]) -> None: ...
global___Honor = Honor

class Interaction(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HISTORY_NODE_FIELD_NUMBER: builtins.int
    GRAPH_VERSION_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    EVALUATION_FIELD_NUMBER: builtins.int
    MARK_FIELD_NUMBER: builtins.int
    @property
    def history_node(self) -> global___Node:
        """"""
        pass
    graph_version: builtins.int
    """"""

    msg: typing.Text
    """"""

    evaluation: typing.Text
    """"""

    mark: builtins.int
    """"""

    def __init__(self,
        *,
        history_node: typing.Optional[global___Node] = ...,
        graph_version: builtins.int = ...,
        msg: typing.Text = ...,
        evaluation: typing.Text = ...,
        mark: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["history_node",b"history_node"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evaluation",b"evaluation","graph_version",b"graph_version","history_node",b"history_node","mark",b"mark","msg",b"msg"]) -> None: ...
global___Interaction = Interaction

class Label(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    ICON_WIDTH_FIELD_NUMBER: builtins.int
    ICON_HEIGHT_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    uri: typing.Text
    """"""

    icon: typing.Text
    """"""

    icon_night: typing.Text
    """"""

    icon_width: builtins.int
    """"""

    icon_height: builtins.int
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        uri: typing.Text = ...,
        icon: typing.Text = ...,
        icon_night: typing.Text = ...,
        icon_width: builtins.int = ...,
        icon_height: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","icon_height",b"icon_height","icon_night",b"icon_night","icon_width",b"icon_width","type",b"type","uri",b"uri"]) -> None: ...
global___Label = Label

class LikeCustom(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIKE_SWITCH_FIELD_NUMBER: builtins.int
    FULL_TO_HALF_PROGRESS_FIELD_NUMBER: builtins.int
    NON_FULL_PROGRESS_FIELD_NUMBER: builtins.int
    UPDATE_COUNT_FIELD_NUMBER: builtins.int
    like_switch: builtins.bool
    """"""

    full_to_half_progress: builtins.int
    """"""

    non_full_progress: builtins.int
    """"""

    update_count: builtins.int
    """"""

    def __init__(self,
        *,
        like_switch: builtins.bool = ...,
        full_to_half_progress: builtins.int = ...,
        non_full_progress: builtins.int = ...,
        update_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_to_half_progress",b"full_to_half_progress","like_switch",b"like_switch","non_full_progress",b"non_full_progress","update_count",b"update_count"]) -> None: ...
global___LikeCustom = LikeCustom

class Live(google.protobuf.message.Message):
    """直播信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    ROOMID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ENDPAGE_URI_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """主播UID"""

    roomid: builtins.int
    """直播间id"""

    uri: typing.Text
    """直播间url"""

    endpage_uri: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        roomid: builtins.int = ...,
        uri: typing.Text = ...,
        endpage_uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpage_uri",b"endpage_uri","mid",b"mid","roomid",b"roomid","uri",b"uri"]) -> None: ...
global___Live = Live

class LiveOrderInfo(google.protobuf.message.Message):
    """直播预约信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LIVE_PLAN_START_TIME_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """预约id"""

    text: typing.Text
    """预约条文案"""

    live_plan_start_time: builtins.int
    """直播开始时间"""

    is_follow: builtins.bool
    """是否预约"""

    def __init__(self,
        *,
        sid: builtins.int = ...,
        text: typing.Text = ...,
        live_plan_start_time: builtins.int = ...,
        is_follow: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow",b"is_follow","live_plan_start_time",b"live_plan_start_time","sid",b"sid","text",b"text"]) -> None: ...
global___LiveOrderInfo = LiveOrderInfo

class NoReply(google.protobuf.message.Message):
    """空回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___NoReply = NoReply

class Node(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NODE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    node_id: builtins.int
    """"""

    title: typing.Text
    """"""

    cid: builtins.int
    """"""

    def __init__(self,
        *,
        node_id: builtins.int = ...,
        title: typing.Text = ...,
        cid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","node_id",b"node_id","title",b"title"]) -> None: ...
global___Node = Node

class Notice(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    desc: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","title",b"title"]) -> None: ...
global___Notice = Notice

class OfficialVerify(google.protobuf.message.Message):
    """认证信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    type: builtins.int
    """认证类型
    0:个人认证 1:官方认证
    """

    desc: typing.Text
    """认证名称"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","type",b"type"]) -> None: ...
global___OfficialVerify = OfficialVerify

class Online(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ONLINE_SHOW_FIELD_NUMBER: builtins.int
    PLAYER_ONLINE_LOGO_FIELD_NUMBER: builtins.int
    online_show: builtins.bool
    """"""

    player_online_logo: typing.Text
    """"""

    def __init__(self,
        *,
        online_show: builtins.bool = ...,
        player_online_logo: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_show",b"online_show","player_online_logo",b"player_online_logo"]) -> None: ...
global___Online = Online

class OnwerExt(google.protobuf.message.Message):
    """UP主扩展信息 ("OnwerExt"为源码中拼写错误)"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    LIVE_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    ASSISTS_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    ARC_COUNT_FIELD_NUMBER: builtins.int
    @property
    def official_verify(self) -> global___OfficialVerify:
        """认证信息"""
        pass
    @property
    def live(self) -> global___Live:
        """直播信息"""
        pass
    @property
    def vip(self) -> global___Vip:
        """会员信息"""
        pass
    @property
    def assists(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
        pass
    fans: builtins.int
    """粉丝数"""

    arc_count: typing.Text
    """总投稿数"""

    def __init__(self,
        *,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        live: typing.Optional[global___Live] = ...,
        vip: typing.Optional[global___Vip] = ...,
        assists: typing.Optional[typing.Iterable[builtins.int]] = ...,
        fans: builtins.int = ...,
        arc_count: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["live",b"live","official_verify",b"official_verify","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count",b"arc_count","assists",b"assists","fans",b"fans","live",b"live","official_verify",b"official_verify","vip",b"vip"]) -> None: ...
global___OnwerExt = OnwerExt

class OperationCard(google.protobuf.message.Message):
    """老运营卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    start_time: builtins.int
    """开始时间(单位为秒)"""

    end_time: builtins.int
    """结束时间(单位为秒)"""

    icon: typing.Text
    """图标"""

    title: typing.Text
    """标题"""

    button_text: typing.Text
    """按钮文案"""

    url: typing.Text
    """跳转链接"""

    content: typing.Text
    """内容描述"""

    def __init__(self,
        *,
        start_time: builtins.int = ...,
        end_time: builtins.int = ...,
        icon: typing.Text = ...,
        title: typing.Text = ...,
        button_text: typing.Text = ...,
        url: typing.Text = ...,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text",b"button_text","content",b"content","end_time",b"end_time","icon",b"icon","start_time",b"start_time","title",b"title","url",b"url"]) -> None: ...
global___OperationCard = OperationCard

class OperationCardNew(google.protobuf.message.Message):
    """内嵌操作按钮卡片"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    STANDARD_FIELD_NUMBER: builtins.int
    SKIP_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    FOLLOW_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    JUMP_FIELD_NUMBER: builtins.int
    GAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """卡片id"""

    to: builtins.int
    """结束时间"""

    status: builtins.bool
    """用户操作态
    true已操作 false未操作
    """

    card_type: global___OperationCardType.ValueType
    """卡片类型"""

    @property
    def standard(self) -> global___StandardCard:
        """标准卡"""
        pass
    @property
    def skip(self) -> global___OperationCard:
        """老运营卡片(原B剪跳转卡)"""
        pass
    biz_type: global___BizType.ValueType
    """"""

    @property
    def follow(self) -> global___BizFollowVideoParam:
        """追番追剧参数"""
        pass
    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
        pass
    @property
    def jump(self) -> global___BizJumpLinkParam:
        """跳转参数"""
        pass
    @property
    def game(self) -> global___BizReserveGameParam:
        """预约游戏参数"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        to: builtins.int = ...,
        status: builtins.bool = ...,
        card_type: global___OperationCardType.ValueType = ...,
        standard: typing.Optional[global___StandardCard] = ...,
        skip: typing.Optional[global___OperationCard] = ...,
        biz_type: global___BizType.ValueType = ...,
        follow: typing.Optional[global___BizFollowVideoParam] = ...,
        reserve: typing.Optional[global___BizReserveActivityParam] = ...,
        jump: typing.Optional[global___BizJumpLinkParam] = ...,
        game: typing.Optional[global___BizReserveGameParam] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["follow",b"follow","game",b"game","jump",b"jump","param",b"param","render",b"render","reserve",b"reserve","skip",b"skip","standard",b"standard"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type",b"biz_type","card_type",b"card_type","follow",b"follow","from",b"from","game",b"game","id",b"id","jump",b"jump","param",b"param","render",b"render","reserve",b"reserve","skip",b"skip","standard",b"standard","status",b"status","to",b"to"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["param",b"param"]) -> typing.Optional[typing_extensions.Literal["follow","reserve","jump","game"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["render",b"render"]) -> typing.Optional[typing_extensions.Literal["standard","skip"]]: ...
global___OperationCardNew = OperationCardNew

class OperationRelate(google.protobuf.message.Message):
    """相关推荐(运营配置+AI推荐)"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    RELATE_ITEM_FIELD_NUMBER: builtins.int
    AI_RELATE_ITEM_FIELD_NUMBER: builtins.int
    title: typing.Text
    """模块标题"""

    @property
    def relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateItem]:
        """相关推荐模块内容"""
        pass
    @property
    def ai_relate_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """AI相关推荐"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        relate_item: typing.Optional[typing.Iterable[global___RelateItem]] = ...,
        ai_relate_item: typing.Optional[typing.Iterable[global___Relate]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_relate_item",b"ai_relate_item","relate_item",b"relate_item","title",b"title"]) -> None: ...
global___OperationRelate = OperationRelate

class Order(google.protobuf.message.Message):
    """预约模块"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STATUS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SEASON_STAT_VIEW_FIELD_NUMBER: builtins.int
    SEASON_STAT_DANMAKU_FIELD_NUMBER: builtins.int
    ORDER_TYPE_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    status: builtins.bool
    """用户操作态"""

    title: typing.Text
    """模块标题"""

    button_title: typing.Text
    """按钮文字 未操作"""

    button_selected_title: typing.Text
    """按钮文字 已操作"""

    season_stat_view: builtins.int
    """合集播放数"""

    season_stat_danmaku: builtins.int
    """合集弹幕数"""

    order_type: global___BizType.ValueType
    """预约类型(点击时透传，直播开始前预约活动，直播开始后收藏合集)"""

    @property
    def reserve(self) -> global___BizReserveActivityParam:
        """预约活动参数"""
        pass
    @property
    def fav_season(self) -> global___BizFavSeasonParam:
        """收藏合集参数"""
        pass
    intro: typing.Text
    """合集简介"""

    def __init__(self,
        *,
        status: builtins.bool = ...,
        title: typing.Text = ...,
        button_title: typing.Text = ...,
        button_selected_title: typing.Text = ...,
        season_stat_view: builtins.int = ...,
        season_stat_danmaku: builtins.int = ...,
        order_type: global___BizType.ValueType = ...,
        reserve: typing.Optional[global___BizReserveActivityParam] = ...,
        fav_season: typing.Optional[global___BizFavSeasonParam] = ...,
        intro: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fav_season",b"fav_season","order_param",b"order_param","reserve",b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title",b"button_selected_title","button_title",b"button_title","fav_season",b"fav_season","intro",b"intro","order_param",b"order_param","order_type",b"order_type","reserve",b"reserve","season_stat_danmaku",b"season_stat_danmaku","season_stat_view",b"season_stat_view","status",b"status","title",b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["order_param",b"order_param"]) -> typing.Optional[typing_extensions.Literal["reserve","fav_season"]]: ...
global___Order = Order

class PackInfo(google.protobuf.message.Message):
    """游戏礼包信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    title: typing.Text
    """礼包标题"""

    uri: typing.Text
    """礼包页uri"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title",b"title","uri",b"uri"]) -> None: ...
global___PackInfo = PackInfo

class PlayerIcon(google.protobuf.message.Message):
    """进度条动画配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL1_FIELD_NUMBER: builtins.int
    HASH1_FIELD_NUMBER: builtins.int
    URL2_FIELD_NUMBER: builtins.int
    HASH2_FIELD_NUMBER: builtins.int
    url1: typing.Text
    """拖动动画配置档url"""

    hash1: typing.Text
    """拖动动画配置档hash"""

    url2: typing.Text
    """松手动画配置档url"""

    hash2: typing.Text
    """松手动画配置档hash"""

    def __init__(self,
        *,
        url1: typing.Text = ...,
        hash1: typing.Text = ...,
        url2: typing.Text = ...,
        hash2: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash1",b"hash1","hash2",b"hash2","url1",b"url1","url2",b"url2"]) -> None: ...
global___PlayerIcon = PlayerIcon

class PointMaterial(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    MATERIAL_SOURCE_FIELD_NUMBER: builtins.int
    url: typing.Text
    """"""

    material_source: builtins.int
    """"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        material_source: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["material_source",b"material_source","url",b"url"]) -> None: ...
global___PointMaterial = PointMaterial

class Rank(google.protobuf.message.Message):
    """排行榜"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """排行榜icon"""

    icon_night: typing.Text
    """排行榜icon 夜间模式"""

    text: typing.Text
    """排行榜文案"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        icon_night: typing.Text = ...,
        text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon","icon_night",b"icon_night","text",b"text"]) -> None: ...
global___Rank = Rank

class ReasonStyle(google.protobuf.message.Message):
    """推荐理由样式"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    text_color: typing.Text
    """日间模式文字"""

    bg_color: typing.Text
    """"""

    border_color: typing.Text
    """"""

    text_color_night: typing.Text
    """夜间模式文字"""

    bg_color_night: typing.Text
    """"""

    border_color_night: typing.Text
    """"""

    bg_style: builtins.int
    """1:填充 2:描边 3:填充 + 描边 4:背景不填充 + 背景不描边"""

    selected: builtins.int
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        bg_color: typing.Text = ...,
        border_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        border_color_night: typing.Text = ...,
        bg_style: builtins.int = ...,
        selected: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_style",b"bg_style","border_color",b"border_color","border_color_night",b"border_color_night","selected",b"selected","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___ReasonStyle = ReasonStyle

class RecDislike(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    CLOSED_SUB_TITLE_FIELD_NUMBER: builtins.int
    PASTE_TEXT_FIELD_NUMBER: builtins.int
    CLOSED_PASTE_TEXT_FIELD_NUMBER: builtins.int
    DISLIKE_REASON_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    CLOSED_TOAST_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    sub_title: typing.Text
    """"""

    closed_sub_title: typing.Text
    """"""

    paste_text: typing.Text
    """"""

    closed_paste_text: typing.Text
    """"""

    @property
    def dislike_reason(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DislikeReasons]:
        """"""
        pass
    toast: typing.Text
    """"""

    closed_toast: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        sub_title: typing.Text = ...,
        closed_sub_title: typing.Text = ...,
        paste_text: typing.Text = ...,
        closed_paste_text: typing.Text = ...,
        dislike_reason: typing.Optional[typing.Iterable[global___DislikeReasons]] = ...,
        toast: typing.Text = ...,
        closed_toast: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed_paste_text",b"closed_paste_text","closed_sub_title",b"closed_sub_title","closed_toast",b"closed_toast","dislike_reason",b"dislike_reason","paste_text",b"paste_text","sub_title",b"sub_title","title",b"title","toast",b"toast"]) -> None: ...
global___RecDislike = RecDislike

class RecThreePoint(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DISLIKE_FIELD_NUMBER: builtins.int
    FEEDBACK_FIELD_NUMBER: builtins.int
    WATCH_LATER_FIELD_NUMBER: builtins.int
    @property
    def dislike(self) -> global___RecDislike:
        """"""
        pass
    @property
    def feedback(self) -> global___RecDislike:
        """"""
        pass
    watch_later: builtins.bool
    """"""

    def __init__(self,
        *,
        dislike: typing.Optional[global___RecDislike] = ...,
        feedback: typing.Optional[global___RecDislike] = ...,
        watch_later: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dislike",b"dislike","feedback",b"feedback"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dislike",b"dislike","feedback",b"feedback","watch_later",b"watch_later"]) -> None: ...
global___RecThreePoint = RecThreePoint

class Relate(google.protobuf.message.Message):
    """相关推荐项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    GOTO_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    RCMD_REASON_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    RATING_COUNT_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    PACK_INFO_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    NEW_CARD_FIELD_NUMBER: builtins.int
    RCMD_REASON_STYLE_FIELD_NUMBER: builtins.int
    COVER_GIF_FIELD_NUMBER: builtins.int
    CM_FIELD_NUMBER: builtins.int
    RESERVE_STATUS_FIELD_NUMBER: builtins.int
    RCMD_REASON_EXTRA_FIELD_NUMBER: builtins.int
    REC_THREE_POINT_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    MATERIAL_ID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    pic: typing.Text
    """封面url"""

    title: typing.Text
    """标题"""

    @property
    def author(self) -> bilibili.app.archive.v1.archive_pb2.Author:
        """UP主信息"""
        pass
    @property
    def stat(self) -> bilibili.app.archive.v1.archive_pb2.Stat:
        """稿件状态数"""
        pass
    duration: builtins.int
    """时长"""

    goto: typing.Text
    """跳转类型
    special:pgc视频 av:稿件视频 cm:广告 game:游戏
    """

    param: typing.Text
    """参数（如av号等）"""

    uri: typing.Text
    """跳转uri"""

    jump_url: typing.Text
    """"""

    rating: builtins.float
    """评分"""

    reserve: typing.Text
    """"""

    desc: typing.Text
    """备注"""

    rcmd_reason: typing.Text
    """"""

    badge: typing.Text
    """标志文字"""

    cid: builtins.int
    """1P cid"""

    season_type: builtins.int
    """"""

    rating_count: builtins.int
    """"""

    tag_name: typing.Text
    """标签文案"""

    @property
    def pack_info(self) -> global___PackInfo:
        """游戏礼包信息"""
        pass
    @property
    def notice(self) -> global___Notice:
        """"""
        pass
    @property
    def button(self) -> global___Button:
        """按钮信息"""
        pass
    trackid: typing.Text
    """spm追踪id"""

    new_card: builtins.int
    """游戏卡片新样式"""

    @property
    def rcmd_reason_style(self) -> global___ReasonStyle:
        """推荐理由样式"""
        pass
    cover_gif: typing.Text
    """"""

    @property
    def cm(self) -> global___CM:
        """广告"""
        pass
    reserve_status: builtins.int
    """游戏卡字段
    0:下载 1:预约(跳过详情) 2:预约 3:测试 4:测试+预约 5:跳过详情页
    """

    rcmd_reason_extra: typing.Text
    """"""

    @property
    def rec_three_point(self) -> global___RecThreePoint:
        """"""
        pass
    unique_id: typing.Text
    """"""

    material_id: builtins.int
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        pic: typing.Text = ...,
        title: typing.Text = ...,
        author: typing.Optional[bilibili.app.archive.v1.archive_pb2.Author] = ...,
        stat: typing.Optional[bilibili.app.archive.v1.archive_pb2.Stat] = ...,
        duration: builtins.int = ...,
        goto: typing.Text = ...,
        param: typing.Text = ...,
        uri: typing.Text = ...,
        jump_url: typing.Text = ...,
        rating: builtins.float = ...,
        reserve: typing.Text = ...,
        desc: typing.Text = ...,
        rcmd_reason: typing.Text = ...,
        badge: typing.Text = ...,
        cid: builtins.int = ...,
        season_type: builtins.int = ...,
        rating_count: builtins.int = ...,
        tag_name: typing.Text = ...,
        pack_info: typing.Optional[global___PackInfo] = ...,
        notice: typing.Optional[global___Notice] = ...,
        button: typing.Optional[global___Button] = ...,
        trackid: typing.Text = ...,
        new_card: builtins.int = ...,
        rcmd_reason_style: typing.Optional[global___ReasonStyle] = ...,
        cover_gif: typing.Text = ...,
        cm: typing.Optional[global___CM] = ...,
        reserve_status: builtins.int = ...,
        rcmd_reason_extra: typing.Text = ...,
        rec_three_point: typing.Optional[global___RecThreePoint] = ...,
        unique_id: typing.Text = ...,
        material_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author",b"author","button",b"button","cm",b"cm","notice",b"notice","pack_info",b"pack_info","rcmd_reason_style",b"rcmd_reason_style","rec_three_point",b"rec_three_point","stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","author",b"author","badge",b"badge","button",b"button","cid",b"cid","cm",b"cm","cover_gif",b"cover_gif","desc",b"desc","duration",b"duration","from",b"from","goto",b"goto","jump_url",b"jump_url","material_id",b"material_id","new_card",b"new_card","notice",b"notice","pack_info",b"pack_info","param",b"param","pic",b"pic","rating",b"rating","rating_count",b"rating_count","rcmd_reason",b"rcmd_reason","rcmd_reason_extra",b"rcmd_reason_extra","rcmd_reason_style",b"rcmd_reason_style","rec_three_point",b"rec_three_point","reserve",b"reserve","reserve_status",b"reserve_status","season_type",b"season_type","stat",b"stat","tag_name",b"tag_name","title",b"title","trackid",b"trackid","unique_id",b"unique_id","uri",b"uri"]) -> None: ...
global___Relate = Relate

class RelateItem(google.protobuf.message.Message):
    """相关推荐内容"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    url: typing.Text
    """跳链"""

    cover: typing.Text
    """封面"""

    def __init__(self,
        *,
        url: typing.Text = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","url",b"url"]) -> None: ...
global___RelateItem = RelateItem

class RelateTab(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    id: typing.Text
    """"""

    title: typing.Text
    """"""

    def __init__(self,
        *,
        id: typing.Text = ...,
        title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","title",b"title"]) -> None: ...
global___RelateTab = RelateTab

class ReqUser(google.protobuf.message.Message):
    """用户操作状态"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTENTION_FIELD_NUMBER: builtins.int
    GUEST_ATTENTION_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    ATTENTION_LEVEL_FIELD_NUMBER: builtins.int
    FAV_SEASON_FIELD_NUMBER: builtins.int
    attention: builtins.int
    """用户是否关注UP"""

    guest_attention: builtins.int
    """UP是否关注用户"""

    favorite: builtins.int
    """是否收藏"""

    like: builtins.int
    """是否点赞"""

    dislike: builtins.int
    """是否点踩"""

    coin: builtins.int
    """是否投币"""

    attention_level: builtins.int
    """关注等级"""

    fav_season: builtins.int
    """是否收藏合集"""

    def __init__(self,
        *,
        attention: builtins.int = ...,
        guest_attention: builtins.int = ...,
        favorite: builtins.int = ...,
        like: builtins.int = ...,
        dislike: builtins.int = ...,
        coin: builtins.int = ...,
        attention_level: builtins.int = ...,
        fav_season: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention",b"attention","attention_level",b"attention_level","coin",b"coin","dislike",b"dislike","fav_season",b"fav_season","favorite",b"favorite","guest_attention",b"guest_attention","like",b"like"]) -> None: ...
global___ReqUser = ReqUser

class Restriction(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_TEENAGERS_FIELD_NUMBER: builtins.int
    IS_LESSONS_FIELD_NUMBER: builtins.int
    IS_REVIEW_FIELD_NUMBER: builtins.int
    DISABLE_RCMD_FIELD_NUMBER: builtins.int
    is_teenagers: builtins.bool
    """"""

    is_lessons: builtins.bool
    """"""

    is_review: builtins.bool
    """"""

    disable_rcmd: builtins.bool
    """"""

    def __init__(self,
        *,
        is_teenagers: builtins.bool = ...,
        is_lessons: builtins.bool = ...,
        is_review: builtins.bool = ...,
        disable_rcmd: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_rcmd",b"disable_rcmd","is_lessons",b"is_lessons","is_review",b"is_review","is_teenagers",b"is_teenagers"]) -> None: ...
global___Restriction = Restriction

class Season(google.protobuf.message.Message):
    """剧集信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ALLOW_DOWNLOAD_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    IS_JUMP_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    IS_FINISH_FIELD_NUMBER: builtins.int
    NEWEST_EP_ID_FIELD_NUMBER: builtins.int
    NEWEST_EP_INDEX_FIELD_NUMBER: builtins.int
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    WEEKDAY_FIELD_NUMBER: builtins.int
    USER_SEASON_FIELD_NUMBER: builtins.int
    PLAYER_FIELD_NUMBER: builtins.int
    OGV_PLAYURL_FIELD_NUMBER: builtins.int
    allow_download: typing.Text
    """"""

    season_id: builtins.int
    """剧集ssid"""

    is_jump: builtins.int
    """是否重定向跳转"""

    title: typing.Text
    """剧集标题"""

    cover: typing.Text
    """剧集封面url"""

    is_finish: builtins.int
    """剧集是否完结"""

    newest_ep_id: builtins.int
    """最新一话epid"""

    newest_ep_index: typing.Text
    """最新一话标题"""

    total_count: builtins.int
    """总集数"""

    weekday: builtins.int
    """更新星期日"""

    @property
    def user_season(self) -> global___UserSeason:
        """用户追番标志"""
        pass
    @property
    def player(self) -> global___SeasonPlayer:
        """"""
        pass
    ogv_playurl: typing.Text
    """单集页面url"""

    def __init__(self,
        *,
        allow_download: typing.Text = ...,
        season_id: builtins.int = ...,
        is_jump: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        is_finish: builtins.int = ...,
        newest_ep_id: builtins.int = ...,
        newest_ep_index: typing.Text = ...,
        total_count: builtins.int = ...,
        weekday: builtins.int = ...,
        user_season: typing.Optional[global___UserSeason] = ...,
        player: typing.Optional[global___SeasonPlayer] = ...,
        ogv_playurl: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player",b"player","user_season",b"user_season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_download",b"allow_download","cover",b"cover","is_finish",b"is_finish","is_jump",b"is_jump","newest_ep_id",b"newest_ep_id","newest_ep_index",b"newest_ep_index","ogv_playurl",b"ogv_playurl","player",b"player","season_id",b"season_id","title",b"title","total_count",b"total_count","user_season",b"user_season","weekday",b"weekday"]) -> None: ...
global___Season = Season

class SeasonPlayer(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    VID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""

    vid: typing.Text
    """"""

    cid: builtins.int
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        vid: typing.Text = ...,
        cid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","from",b"from","vid",b"vid"]) -> None: ...
global___SeasonPlayer = SeasonPlayer

class SeasonReply(google.protobuf.message.Message):
    """合集详情页-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_FIELD_NUMBER: builtins.int
    @property
    def season(self) -> global___UgcSeason:
        """合集信息"""
        pass
    def __init__(self,
        *,
        season: typing.Optional[global___UgcSeason] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["season",b"season"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["season",b"season"]) -> None: ...
global___SeasonReply = SeasonReply

class SeasonReq(google.protobuf.message.Message):
    """合集详情页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["season_id",b"season_id"]) -> None: ...
global___SeasonReq = SeasonReq

class Section(google.protobuf.message.Message):
    """视频合集小节信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    EPISODES_FIELD_NUMBER: builtins.int
    id: builtins.int
    """小节id"""

    title: typing.Text
    """小节标题"""

    type: builtins.int
    """小节类型
    0:其他 1:正片
    """

    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Episode]:
        """单话列表"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        type: builtins.int = ...,
        episodes: typing.Optional[typing.Iterable[global___Episode]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["episodes",b"episodes","id",b"id","title",b"title","type",b"type"]) -> None: ...
global___Section = Section

class ShortFormVideoDownloadReply(google.protobuf.message.Message):
    """短视频下载-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HAS_DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    BACKUP_DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    has_download_url: builtins.bool
    """是否有下载分享按钮"""

    download_url: typing.Text
    """下载url"""

    md5: typing.Text
    """文件md5"""

    size: builtins.int
    """文件大小(单位为Byte)"""

    backup_download_url: typing.Text
    """"""

    def __init__(self,
        *,
        has_download_url: builtins.bool = ...,
        download_url: typing.Text = ...,
        md5: typing.Text = ...,
        size: builtins.int = ...,
        backup_download_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_download_url",b"backup_download_url","download_url",b"download_url","has_download_url",b"has_download_url","md5",b"md5","size",b"size"]) -> None: ...
global___ShortFormVideoDownloadReply = ShortFormVideoDownloadReply

class ShortFormVideoDownloadReq(google.protobuf.message.Message):
    """短视频下载-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    RESTRICTION_FIELD_NUMBER: builtins.int
    TF_ISP_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    mid: builtins.int
    """用户mid"""

    buvid: typing.Text
    """设备buvid"""

    mobi_app: typing.Text
    """移动端包类型"""

    build: builtins.int
    """移动端版本号"""

    device: typing.Text
    """运行设备"""

    platform: typing.Text
    """平台"""

    spmid: typing.Text
    """当前页面spm"""

    @property
    def restriction(self) -> global___Restriction:
        """"""
        pass
    tf_isp: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        mid: builtins.int = ...,
        buvid: typing.Text = ...,
        mobi_app: typing.Text = ...,
        build: builtins.int = ...,
        device: typing.Text = ...,
        platform: typing.Text = ...,
        spmid: typing.Text = ...,
        restriction: typing.Optional[global___Restriction] = ...,
        tf_isp: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["restriction",b"restriction"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","build",b"build","buvid",b"buvid","cid",b"cid","device",b"device","mid",b"mid","mobi_app",b"mobi_app","platform",b"platform","restriction",b"restriction","spmid",b"spmid","tf_isp",b"tf_isp"]) -> None: ...
global___ShortFormVideoDownloadReq = ShortFormVideoDownloadReq

class SpecialCell(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    ICON_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    CELL_TYPE_FIELD_NUMBER: builtins.int
    CELL_BGCOLOR_FIELD_NUMBER: builtins.int
    CELL_BGCOLOR_NIGHT_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    PAGE_TITLE_FIELD_NUMBER: builtins.int
    JUMP_TYPE_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """"""

    icon_night: typing.Text
    """"""

    text: typing.Text
    """"""

    text_color: typing.Text
    """"""

    text_color_night: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    cell_type: typing.Text
    """"""

    cell_bgcolor: typing.Text
    """"""

    cell_bgcolor_night: typing.Text
    """"""

    param: typing.Text
    """"""

    page_title: typing.Text
    """"""

    jump_type: typing.Text
    """"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        icon_night: typing.Text = ...,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        jump_url: typing.Text = ...,
        cell_type: typing.Text = ...,
        cell_bgcolor: typing.Text = ...,
        cell_bgcolor_night: typing.Text = ...,
        param: typing.Text = ...,
        page_title: typing.Text = ...,
        jump_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cell_bgcolor",b"cell_bgcolor","cell_bgcolor_night",b"cell_bgcolor_night","cell_type",b"cell_type","icon",b"icon","icon_night",b"icon_night","jump_type",b"jump_type","jump_url",b"jump_url","page_title",b"page_title","param",b"param","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___SpecialCell = SpecialCell

class Staff(google.protobuf.message.Message):
    """合作成员信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_FIELD_NUMBER: builtins.int
    VIP_FIELD_NUMBER: builtins.int
    ATTENTION_FIELD_NUMBER: builtins.int
    LABEL_STYLE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """成员mid"""

    title: typing.Text
    """成员角色"""

    face: typing.Text
    """成员头像url"""

    name: typing.Text
    """成员昵称"""

    @property
    def official_verify(self) -> global___OfficialVerify:
        """成员官方信息"""
        pass
    @property
    def vip(self) -> global___Vip:
        """成员会员信息"""
        pass
    attention: builtins.int
    """是否关注该成员"""

    label_style: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        face: typing.Text = ...,
        name: typing.Text = ...,
        official_verify: typing.Optional[global___OfficialVerify] = ...,
        vip: typing.Optional[global___Vip] = ...,
        attention: builtins.int = ...,
        label_style: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["official_verify",b"official_verify","vip",b"vip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention",b"attention","face",b"face","label_style",b"label_style","mid",b"mid","name",b"name","official_verify",b"official_verify","title",b"title","vip",b"vip"]) -> None: ...
global___Staff = Staff

class StandardCard(google.protobuf.message.Message):
    """标准卡"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    BUTTON_TITLE_FIELD_NUMBER: builtins.int
    BUTTON_SELECTED_TITLE_FIELD_NUMBER: builtins.int
    SHOW_SELECTED_FIELD_NUMBER: builtins.int
    title: typing.Text
    """卡片文案"""

    button_title: typing.Text
    """按钮文字 未操作"""

    button_selected_title: typing.Text
    """按钮文字 已操作"""

    show_selected: builtins.bool
    """已操作态是否显示"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        button_title: typing.Text = ...,
        button_selected_title: typing.Text = ...,
        show_selected: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_selected_title",b"button_selected_title","button_title",b"button_title","show_selected",b"show_selected","title",b"title"]) -> None: ...
global___StandardCard = StandardCard

class TFPanelCustomized(google.protobuf.message.Message):
    """免流面板定制"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class SubPanelEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___subTFPanel: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___subTFPanel] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    RIGHT_BTN_IMG_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RIGHT_BTN_LINK_FIELD_NUMBER: builtins.int
    MAIN_LABEL_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    SUB_PANEL_FIELD_NUMBER: builtins.int
    right_btn_img: typing.Text
    """右侧按钮素材"""

    right_btn_text: typing.Text
    """右侧按钮文案"""

    right_btn_text_color: typing.Text
    """右侧按钮字体颜色"""

    right_btn_link: typing.Text
    """右侧按钮跳转链接"""

    main_label: typing.Text
    """中心主文案内容"""

    operator: typing.Text
    """运营商(cm ct cu)"""

    @property
    def sub_panel(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___subTFPanel]:
        """子面板定制化配置"""
        pass
    def __init__(self,
        *,
        right_btn_img: typing.Text = ...,
        right_btn_text: typing.Text = ...,
        right_btn_text_color: typing.Text = ...,
        right_btn_link: typing.Text = ...,
        main_label: typing.Text = ...,
        operator: typing.Text = ...,
        sub_panel: typing.Optional[typing.Mapping[typing.Text, global___subTFPanel]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_label",b"main_label","operator",b"operator","right_btn_img",b"right_btn_img","right_btn_link",b"right_btn_link","right_btn_text",b"right_btn_text","right_btn_text_color",b"right_btn_text_color","sub_panel",b"sub_panel"]) -> None: ...
global___TFPanelCustomized = TFPanelCustomized

class TIcon(google.protobuf.message.Message):
    """TAG图标信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ICON_FIELD_NUMBER: builtins.int
    icon: typing.Text
    """TAG图标url"""

    def __init__(self,
        *,
        icon: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon",b"icon"]) -> None: ...
global___TIcon = TIcon

class Tab(google.protobuf.message.Message):
    """TAB"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_FIELD_NUMBER: builtins.int
    OTYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_SELECTED_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    AD_TAB_INFO_FIELD_NUMBER: builtins.int
    background: typing.Text
    """背景图片"""

    otype: global___TabOtype.ValueType
    """跳转类型"""

    oid: builtins.int
    """类型id"""

    uri: typing.Text
    """跳转url"""

    style: global___TabStyle.ValueType
    """样式"""

    text: typing.Text
    """文字"""

    text_color: typing.Text
    """未选中态字色"""

    text_color_selected: typing.Text
    """选中态字色"""

    pic: typing.Text
    """图片"""

    id: builtins.int
    """后台配置自增"""

    @property
    def ad_tab_info(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        background: typing.Text = ...,
        otype: global___TabOtype.ValueType = ...,
        oid: builtins.int = ...,
        uri: typing.Text = ...,
        style: global___TabStyle.ValueType = ...,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_selected: typing.Text = ...,
        pic: typing.Text = ...,
        id: builtins.int = ...,
        ad_tab_info: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ad_tab_info",b"ad_tab_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_tab_info",b"ad_tab_info","background",b"background","id",b"id","oid",b"oid","otype",b"otype","pic",b"pic","style",b"style","text",b"text","text_color",b"text_color","text_color_selected",b"text_color_selected","uri",b"uri"]) -> None: ...
global___Tab = Tab

class Tag(google.protobuf.message.Message):
    """TAG信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    HATES_FIELD_NUMBER: builtins.int
    LIKED_FIELD_NUMBER: builtins.int
    HATED_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TAG_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """TAD id"""

    name: typing.Text
    """TAG名"""

    likes: builtins.int
    """"""

    hates: builtins.int
    """"""

    liked: builtins.int
    """"""

    hated: builtins.int
    """"""

    uri: typing.Text
    """TAG页面uri"""

    tag_type: typing.Text
    """TAG类型
    common:普通 new:话题 act:活动
    """

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        likes: builtins.int = ...,
        hates: builtins.int = ...,
        liked: builtins.int = ...,
        hated: builtins.int = ...,
        uri: typing.Text = ...,
        tag_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hated",b"hated","hates",b"hates","id",b"id","liked",b"liked","likes",b"likes","name",b"name","tag_type",b"tag_type","uri",b"uri"]) -> None: ...
global___Tag = Tag

class UgcSeason(google.protobuf.message.Message):
    """UGC视频合集信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    INTRO_FIELD_NUMBER: builtins.int
    SECTIONS_FIELD_NUMBER: builtins.int
    STAT_FIELD_NUMBER: builtins.int
    LABEL_TEXT_FIELD_NUMBER: builtins.int
    LABEL_TEXT_COLOR_FIELD_NUMBER: builtins.int
    LABEL_BG_COLOR_FIELD_NUMBER: builtins.int
    LABEL_TEXT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    LABEL_BG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    DESCRIGHT_FIELD_NUMBER: builtins.int
    EP_COUNT_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    SHOW_CONTINUAL_BUTTON_FIELD_NUMBER: builtins.int
    id: builtins.int
    """合集id"""

    title: typing.Text
    """合集标题"""

    cover: typing.Text
    """合集封面url"""

    intro: typing.Text
    """合集简介"""

    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Section]:
        """小节列表"""
        pass
    @property
    def stat(self) -> global___UgcSeasonStat:
        """合集状态数"""
        pass
    label_text: typing.Text
    """标签字色"""

    label_text_color: typing.Text
    """标签背景色"""

    label_bg_color: typing.Text
    """标签夜间字色"""

    label_text_night_color: typing.Text
    """标签夜间背景色"""

    label_bg_night_color: typing.Text
    """右侧描述文案"""

    descRight: typing.Text
    """按钮文案"""

    ep_count: builtins.int
    """分集总数"""

    season_type: global___SeasonType.ValueType
    """合集类型"""

    show_continual_button: builtins.bool
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        cover: typing.Text = ...,
        intro: typing.Text = ...,
        sections: typing.Optional[typing.Iterable[global___Section]] = ...,
        stat: typing.Optional[global___UgcSeasonStat] = ...,
        label_text: typing.Text = ...,
        label_text_color: typing.Text = ...,
        label_bg_color: typing.Text = ...,
        label_text_night_color: typing.Text = ...,
        label_bg_night_color: typing.Text = ...,
        descRight: typing.Text = ...,
        ep_count: builtins.int = ...,
        season_type: global___SeasonType.ValueType = ...,
        show_continual_button: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["stat",b"stat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","descRight",b"descRight","ep_count",b"ep_count","id",b"id","intro",b"intro","label_bg_color",b"label_bg_color","label_bg_night_color",b"label_bg_night_color","label_text",b"label_text","label_text_color",b"label_text_color","label_text_night_color",b"label_text_night_color","season_type",b"season_type","sections",b"sections","show_continual_button",b"show_continual_button","stat",b"stat","title",b"title"]) -> None: ...
global___UgcSeason = UgcSeason

class UgcSeasonStat(google.protobuf.message.Message):
    """ugc视频合集状态数"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    REPLY_FIELD_NUMBER: builtins.int
    FAV_FIELD_NUMBER: builtins.int
    COIN_FIELD_NUMBER: builtins.int
    SHARE_FIELD_NUMBER: builtins.int
    NOW_RANK_FIELD_NUMBER: builtins.int
    HIS_RANK_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """合集id"""

    view: builtins.int
    """观看数"""

    danmaku: builtins.int
    """弹幕数"""

    reply: builtins.int
    """评论数"""

    fav: builtins.int
    """收藏数"""

    coin: builtins.int
    """投币数"""

    share: builtins.int
    """分享数"""

    now_rank: builtins.int
    """当前排名"""

    his_rank: builtins.int
    """历史最高排名"""

    like: builtins.int
    """总计点赞"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        view: builtins.int = ...,
        danmaku: builtins.int = ...,
        reply: builtins.int = ...,
        fav: builtins.int = ...,
        coin: builtins.int = ...,
        share: builtins.int = ...,
        now_rank: builtins.int = ...,
        his_rank: builtins.int = ...,
        like: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin",b"coin","danmaku",b"danmaku","fav",b"fav","his_rank",b"his_rank","like",b"like","now_rank",b"now_rank","reply",b"reply","season_id",b"season_id","share",b"share","view",b"view"]) -> None: ...
global___UgcSeasonStat = UgcSeasonStat

class UpAct(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    STATEMENT_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    sid: builtins.int
    """"""

    mid: builtins.int
    """"""

    title: typing.Text
    """"""

    statement: typing.Text
    """"""

    image: typing.Text
    """"""

    url: typing.Text
    """"""

    button: typing.Text
    """"""

    def __init__(self,
        *,
        sid: builtins.int = ...,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        statement: typing.Text = ...,
        image: typing.Text = ...,
        url: typing.Text = ...,
        button: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button",b"button","image",b"image","mid",b"mid","sid",b"sid","statement",b"statement","title",b"title","url",b"url"]) -> None: ...
global___UpAct = UpAct

class UpLikeImg(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRE_IMG_FIELD_NUMBER: builtins.int
    SUC_IMG_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    pre_img: typing.Text
    """"""

    suc_img: typing.Text
    """"""

    content: typing.Text
    """"""

    def __init__(self,
        *,
        pre_img: typing.Text = ...,
        suc_img: typing.Text = ...,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","pre_img",b"pre_img","suc_img",b"suc_img"]) -> None: ...
global___UpLikeImg = UpLikeImg

class UpperInfos(google.protobuf.message.Message):
    """UP主信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FANS_COUNT_FIELD_NUMBER: builtins.int
    ARC_COUNT_LAST_HALF_YEAR_FIELD_NUMBER: builtins.int
    FIRST_UP_DATES_FIELD_NUMBER: builtins.int
    TOTAL_PLAY_COUNT_FIELD_NUMBER: builtins.int
    fans_count: builtins.int
    """粉丝数"""

    arc_count_last_half_year: builtins.int
    """近半年投稿数"""

    first_up_dates: builtins.int
    """成为UP主时间"""

    total_play_count: builtins.int
    """总播放量"""

    def __init__(self,
        *,
        fans_count: builtins.int = ...,
        arc_count_last_half_year: builtins.int = ...,
        first_up_dates: builtins.int = ...,
        total_play_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_count_last_half_year",b"arc_count_last_half_year","fans_count",b"fans_count","first_up_dates",b"first_up_dates","total_play_count",b"total_play_count"]) -> None: ...
global___UpperInfos = UpperInfos

class UserGarb(google.protobuf.message.Message):
    """用户装扮信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_IMAGE_ANI_CUT_FIELD_NUMBER: builtins.int
    url_image_ani_cut: typing.Text
    """点赞动画url"""

    def __init__(self,
        *,
        url_image_ani_cut: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url_image_ani_cut",b"url_image_ani_cut"]) -> None: ...
global___UserGarb = UserGarb

class UserSeason(google.protobuf.message.Message):
    """用户追番标志"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTENTION_FIELD_NUMBER: builtins.int
    attention: typing.Text
    """关注状态
    0:未关注 1:已关注
    """

    def __init__(self,
        *,
        attention: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention",b"attention"]) -> None: ...
global___UserSeason = UserSeason

class VideoGuide(google.protobuf.message.Message):
    """视频引导信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ATTENTION_FIELD_NUMBER: builtins.int
    COMMANDDMS_FIELD_NUMBER: builtins.int
    OPERATION_CARD_FIELD_NUMBER: builtins.int
    OPERATION_CARD_NEW_FIELD_NUMBER: builtins.int
    CONTRACT_CARD_FIELD_NUMBER: builtins.int
    @property
    def attention(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Attention]:
        """关注按钮卡片"""
        pass
    @property
    def commandDms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """互动弹幕"""
        pass
    @property
    def operation_card(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCard]:
        """运营卡片"""
        pass
    @property
    def operation_card_new(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperationCardNew]:
        """运营卡片新版"""
        pass
    @property
    def contract_card(self) -> global___ContractCard:
        """契约卡"""
        pass
    def __init__(self,
        *,
        attention: typing.Optional[typing.Iterable[global___Attention]] = ...,
        commandDms: typing.Optional[typing.Iterable[global___CommandDm]] = ...,
        operation_card: typing.Optional[typing.Iterable[global___OperationCard]] = ...,
        operation_card_new: typing.Optional[typing.Iterable[global___OperationCardNew]] = ...,
        contract_card: typing.Optional[global___ContractCard] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["contract_card",b"contract_card"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attention",b"attention","commandDms",b"commandDms","contract_card",b"contract_card","operation_card",b"operation_card","operation_card_new",b"operation_card_new"]) -> None: ...
global___VideoGuide = VideoGuide

class VideoPoint(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LOGO_URL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    to: builtins.int
    """"""

    content: typing.Text
    """"""

    cover: typing.Text
    """"""

    logo_url: typing.Text
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        to: builtins.int = ...,
        content: typing.Text = ...,
        cover: typing.Text = ...,
        logo_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","cover",b"cover","from",b"from","logo_url",b"logo_url","to",b"to","type",b"type"]) -> None: ...
global___VideoPoint = VideoPoint

class VideoShot(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PV_DATA_FIELD_NUMBER: builtins.int
    IMG_X_LEN_FIELD_NUMBER: builtins.int
    IMG_Y_LEN_FIELD_NUMBER: builtins.int
    IMG_X_SIZE_FIELD_NUMBER: builtins.int
    IMG_Y_SIZE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    pv_data: typing.Text
    """"""

    img_x_len: builtins.int
    """"""

    img_y_len: builtins.int
    """"""

    img_x_size: builtins.int
    """"""

    img_y_size: builtins.int
    """"""

    @property
    def image(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """"""
        pass
    def __init__(self,
        *,
        pv_data: typing.Text = ...,
        img_x_len: builtins.int = ...,
        img_y_len: builtins.int = ...,
        img_x_size: builtins.int = ...,
        img_y_size: builtins.int = ...,
        image: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image",b"image","img_x_len",b"img_x_len","img_x_size",b"img_x_size","img_y_len",b"img_y_len","img_y_size",b"img_y_size","pv_data",b"pv_data"]) -> None: ...
global___VideoShot = VideoShot

class ViewMaterial(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """"""

    mid: builtins.int
    """"""

    title: typing.Text
    """"""

    author: typing.Text
    """"""

    jump_url: typing.Text
    """"""

    def __init__(self,
        *,
        oid: builtins.int = ...,
        mid: builtins.int = ...,
        title: typing.Text = ...,
        author: typing.Text = ...,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author",b"author","jump_url",b"jump_url","mid",b"mid","oid",b"oid","title",b"title"]) -> None: ...
global___ViewMaterial = ViewMaterial

class ViewPage(google.protobuf.message.Message):
    """分P信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    DM_FIELD_NUMBER: builtins.int
    DOWNLOAD_TITLE_FIELD_NUMBER: builtins.int
    DOWNLOAD_SUBTITLE_FIELD_NUMBER: builtins.int
    @property
    def page(self) -> bilibili.app.archive.v1.archive_pb2.Page:
        """分P基本信息"""
        pass
    @property
    def audio(self) -> global___Audio:
        """分P对应的音频稿件"""
        pass
    @property
    def dm(self) -> global___DM:
        """分P弹幕信息"""
        pass
    download_title: typing.Text
    """下载文案"""

    download_subtitle: typing.Text
    """分P完整标题(视频标题+分P标题)"""

    def __init__(self,
        *,
        page: typing.Optional[bilibili.app.archive.v1.archive_pb2.Page] = ...,
        audio: typing.Optional[global___Audio] = ...,
        dm: typing.Optional[global___DM] = ...,
        download_title: typing.Text = ...,
        download_subtitle: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio",b"audio","dm",b"dm","page",b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio",b"audio","dm",b"dm","download_subtitle",b"download_subtitle","download_title",b"download_title","page",b"page"]) -> None: ...
global___ViewPage = ViewPage

class ViewProgressReply(google.protobuf.message.Message):
    """稿件播放中数据-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_GUIDE_FIELD_NUMBER: builtins.int
    CHRONOS_FIELD_NUMBER: builtins.int
    ARC_SHOT_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    POINT_MATERIAL_FIELD_NUMBER: builtins.int
    POINT_PERMANENT_FIELD_NUMBER: builtins.int
    BUZZWORD_PERIODS_FIELD_NUMBER: builtins.int
    @property
    def video_guide(self) -> global___VideoGuide:
        """视频引导信息"""
        pass
    @property
    def chronos(self) -> global___Chronos:
        """Chronos灰度管理"""
        pass
    @property
    def arc_shot(self) -> global___VideoShot:
        """视频快照"""
        pass
    @property
    def points(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoPoint]:
        """"""
        pass
    @property
    def point_material(self) -> global___PointMaterial:
        """"""
        pass
    point_permanent: builtins.bool
    """"""

    @property
    def buzzword_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BuzzwordConfig]:
        """名词解释列表"""
        pass
    def __init__(self,
        *,
        video_guide: typing.Optional[global___VideoGuide] = ...,
        chronos: typing.Optional[global___Chronos] = ...,
        arc_shot: typing.Optional[global___VideoShot] = ...,
        points: typing.Optional[typing.Iterable[global___VideoPoint]] = ...,
        point_material: typing.Optional[global___PointMaterial] = ...,
        point_permanent: builtins.bool = ...,
        buzzword_periods: typing.Optional[typing.Iterable[global___BuzzwordConfig]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["arc_shot",b"arc_shot","chronos",b"chronos","point_material",b"point_material","video_guide",b"video_guide"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arc_shot",b"arc_shot","buzzword_periods",b"buzzword_periods","chronos",b"chronos","point_material",b"point_material","point_permanent",b"point_permanent","points",b"points","video_guide",b"video_guide"]) -> None: ...
global___ViewProgressReply = ViewProgressReply

class ViewProgressReq(google.protobuf.message.Message):
    """稿件播放中数据-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    MESSAGE_PROTOCOL_FIELD_NUMBER: builtins.int
    SERVICE_KEY_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid"""

    cid: builtins.int
    """视频cid"""

    up_mid: builtins.int
    """UP主mid"""

    engine_version: typing.Text
    """"""

    message_protocol: typing.Text
    """"""

    service_key: typing.Text
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        up_mid: builtins.int = ...,
        engine_version: typing.Text = ...,
        message_protocol: typing.Text = ...,
        service_key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","engine_version",b"engine_version","message_protocol",b"message_protocol","service_key",b"service_key","up_mid",b"up_mid"]) -> None: ...
global___ViewProgressReq = ViewProgressReq

class ViewReply(google.protobuf.message.Message):
    """视频页信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class TIconEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___TIcon: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___TIcon] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    ARC_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    OWNER_EXT_FIELD_NUMBER: builtins.int
    REQ_USER_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    T_ICON_FIELD_NUMBER: builtins.int
    SEASON_FIELD_NUMBER: builtins.int
    ELEC_RANK_FIELD_NUMBER: builtins.int
    HISTORY_FIELD_NUMBER: builtins.int
    RELATES_FIELD_NUMBER: builtins.int
    DISLIKE_FIELD_NUMBER: builtins.int
    PLAYER_ICON_FIELD_NUMBER: builtins.int
    VIP_ACTIVE_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    HONOR_FIELD_NUMBER: builtins.int
    RELATE_TAB_FIELD_NUMBER: builtins.int
    ACTIVITY_URL_FIELD_NUMBER: builtins.int
    BGM_FIELD_NUMBER: builtins.int
    STAFF_FIELD_NUMBER: builtins.int
    ARGUE_MSG_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    PLAY_PARAM_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    UGC_SEASON_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    INTERACTION_FIELD_NUMBER: builtins.int
    ECODE_FIELD_NUMBER: builtins.int
    CUSTOM_CONFIG_FIELD_NUMBER: builtins.int
    CMS_FIELD_NUMBER: builtins.int
    CM_CONFIG_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    TF_PANEL_CUSTOMIZED_FIELD_NUMBER: builtins.int
    UP_ACT_FIELD_NUMBER: builtins.int
    USER_GARB_FIELD_NUMBER: builtins.int
    ACTIVITY_SEASON_FIELD_NUMBER: builtins.int
    BADGE_URL_FIELD_NUMBER: builtins.int
    LIVE_ORDER_INFO_FIELD_NUMBER: builtins.int
    DESC_V2_FIELD_NUMBER: builtins.int
    CM_IPAD_FIELD_NUMBER: builtins.int
    STICKER_FIELD_NUMBER: builtins.int
    UP_LIKE_IMG_FIELD_NUMBER: builtins.int
    LIKE_CUSTOM_FIELD_NUMBER: builtins.int
    DESC_TAG_FIELD_NUMBER: builtins.int
    SPECIAL_CELL_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    CM_UNDER_PLAYER_FIELD_NUMBER: builtins.int
    @property
    def arc(self) -> bilibili.app.archive.v1.archive_pb2.Arc:
        """稿件信息"""
        pass
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewPage]:
        """分P信息"""
        pass
    @property
    def owner_ext(self) -> global___OnwerExt:
        """UP主扩展信息 ("OnwerExt"为源码中拼写错误)"""
        pass
    @property
    def req_user(self) -> global___ReqUser:
        """稿件用户操作状态"""
        pass
    @property
    def tag(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """稿件TAG"""
        pass
    @property
    def t_icon(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___TIcon]:
        """TAG对应的图标"""
        pass
    @property
    def season(self) -> global___Season:
        """稿件映射的PGC剧集信息"""
        pass
    @property
    def elec_rank(self) -> global___ElecRank:
        """充电排行"""
        pass
    @property
    def history(self) -> global___History:
        """历史观看进度"""
        pass
    @property
    def relates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Relate]:
        """视频相关推荐列表"""
        pass
    @property
    def dislike(self) -> global___Dislike:
        """不感兴趣原因"""
        pass
    @property
    def player_icon(self) -> global___PlayerIcon:
        """播放图标动画配置档"""
        pass
    vip_active: typing.Text
    """"""

    bvid: typing.Text
    """稿件bvid"""

    @property
    def honor(self) -> global___Honor:
        """获得荣誉信息"""
        pass
    @property
    def relate_tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RelateTab]:
        """相关推荐顶部tab"""
        pass
    activity_url: typing.Text
    """参与的活动页面url"""

    @property
    def bgm(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Bgm]:
        """稿件引用bgm列表"""
        pass
    @property
    def staff(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Staff]:
        """联合投稿成员列表"""
        pass
    argue_msg: typing.Text
    """争议信息"""

    short_link: typing.Text
    """短链接"""

    play_param: builtins.int
    """播放实验
    1:相关推荐自动播放
    """

    @property
    def label(self) -> global___Label:
        """标签"""
        pass
    @property
    def ugc_season(self) -> global___UgcSeason:
        """UGC视频合集信息"""
        pass
    @property
    def config(self) -> global___Config:
        """配置信息"""
        pass
    share_subtitle: typing.Text
    """分享副标题(已观看xxx次)"""

    @property
    def interaction(self) -> global___Interaction:
        """互动视频信息"""
        pass
    ecode: global___ECode.ValueType
    """错误码
    DEFAULT:正常 CODE404:视频被UP主删除
    """

    @property
    def custom_config(self) -> global___CustomConfig:
        """404页信息"""
        pass
    @property
    def cms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CM]:
        """广告"""
        pass
    @property
    def cm_config(self) -> global___CMConfig:
        """广告配置"""
        pass
    @property
    def tab(self) -> global___Tab:
        """播放页定制tab"""
        pass
    @property
    def rank(self) -> global___Rank:
        """排行榜"""
        pass
    @property
    def tf_panel_customized(self) -> global___TFPanelCustomized:
        """免流面板定制"""
        pass
    @property
    def up_act(self) -> global___UpAct:
        """UP主发起活动"""
        pass
    @property
    def user_garb(self) -> global___UserGarb:
        """用户装扮"""
        pass
    @property
    def activity_season(self) -> global___ActivitySeason:
        """大型活动合集"""
        pass
    badge_url: typing.Text
    """评论样式"""

    @property
    def live_order_info(self) -> global___LiveOrderInfo:
        """直播预约信息"""
        pass
    @property
    def desc_v2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DescV2]:
        """稿件简介v2"""
        pass
    @property
    def cm_ipad(self) -> global___CmIpad:
        """"""
        pass
    @property
    def sticker(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ViewMaterial]:
        """"""
        pass
    @property
    def up_like_img(self) -> global___UpLikeImg:
        """"""
        pass
    @property
    def like_custom(self) -> global___LikeCustom:
        """"""
        pass
    @property
    def desc_tag(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]:
        """"""
        pass
    @property
    def special_cell(self) -> global___SpecialCell:
        """"""
        pass
    @property
    def online(self) -> global___Online:
        """"""
        pass
    @property
    def cm_under_player(self) -> google.protobuf.any_pb2.Any:
        """"""
        pass
    def __init__(self,
        *,
        arc: typing.Optional[bilibili.app.archive.v1.archive_pb2.Arc] = ...,
        pages: typing.Optional[typing.Iterable[global___ViewPage]] = ...,
        owner_ext: typing.Optional[global___OnwerExt] = ...,
        req_user: typing.Optional[global___ReqUser] = ...,
        tag: typing.Optional[typing.Iterable[global___Tag]] = ...,
        t_icon: typing.Optional[typing.Mapping[typing.Text, global___TIcon]] = ...,
        season: typing.Optional[global___Season] = ...,
        elec_rank: typing.Optional[global___ElecRank] = ...,
        history: typing.Optional[global___History] = ...,
        relates: typing.Optional[typing.Iterable[global___Relate]] = ...,
        dislike: typing.Optional[global___Dislike] = ...,
        player_icon: typing.Optional[global___PlayerIcon] = ...,
        vip_active: typing.Text = ...,
        bvid: typing.Text = ...,
        honor: typing.Optional[global___Honor] = ...,
        relate_tab: typing.Optional[typing.Iterable[global___RelateTab]] = ...,
        activity_url: typing.Text = ...,
        bgm: typing.Optional[typing.Iterable[global___Bgm]] = ...,
        staff: typing.Optional[typing.Iterable[global___Staff]] = ...,
        argue_msg: typing.Text = ...,
        short_link: typing.Text = ...,
        play_param: builtins.int = ...,
        label: typing.Optional[global___Label] = ...,
        ugc_season: typing.Optional[global___UgcSeason] = ...,
        config: typing.Optional[global___Config] = ...,
        share_subtitle: typing.Text = ...,
        interaction: typing.Optional[global___Interaction] = ...,
        ecode: global___ECode.ValueType = ...,
        custom_config: typing.Optional[global___CustomConfig] = ...,
        cms: typing.Optional[typing.Iterable[global___CM]] = ...,
        cm_config: typing.Optional[global___CMConfig] = ...,
        tab: typing.Optional[global___Tab] = ...,
        rank: typing.Optional[global___Rank] = ...,
        tf_panel_customized: typing.Optional[global___TFPanelCustomized] = ...,
        up_act: typing.Optional[global___UpAct] = ...,
        user_garb: typing.Optional[global___UserGarb] = ...,
        activity_season: typing.Optional[global___ActivitySeason] = ...,
        badge_url: typing.Text = ...,
        live_order_info: typing.Optional[global___LiveOrderInfo] = ...,
        desc_v2: typing.Optional[typing.Iterable[global___DescV2]] = ...,
        cm_ipad: typing.Optional[global___CmIpad] = ...,
        sticker: typing.Optional[typing.Iterable[global___ViewMaterial]] = ...,
        up_like_img: typing.Optional[global___UpLikeImg] = ...,
        like_custom: typing.Optional[global___LikeCustom] = ...,
        desc_tag: typing.Optional[typing.Iterable[global___Tag]] = ...,
        special_cell: typing.Optional[global___SpecialCell] = ...,
        online: typing.Optional[global___Online] = ...,
        cm_under_player: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity_season",b"activity_season","arc",b"arc","cm_config",b"cm_config","cm_ipad",b"cm_ipad","cm_under_player",b"cm_under_player","config",b"config","custom_config",b"custom_config","dislike",b"dislike","elec_rank",b"elec_rank","history",b"history","honor",b"honor","interaction",b"interaction","label",b"label","like_custom",b"like_custom","live_order_info",b"live_order_info","online",b"online","owner_ext",b"owner_ext","player_icon",b"player_icon","rank",b"rank","req_user",b"req_user","season",b"season","special_cell",b"special_cell","tab",b"tab","tf_panel_customized",b"tf_panel_customized","ugc_season",b"ugc_season","up_act",b"up_act","up_like_img",b"up_like_img","user_garb",b"user_garb"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_season",b"activity_season","activity_url",b"activity_url","arc",b"arc","argue_msg",b"argue_msg","badge_url",b"badge_url","bgm",b"bgm","bvid",b"bvid","cm_config",b"cm_config","cm_ipad",b"cm_ipad","cm_under_player",b"cm_under_player","cms",b"cms","config",b"config","custom_config",b"custom_config","desc_tag",b"desc_tag","desc_v2",b"desc_v2","dislike",b"dislike","ecode",b"ecode","elec_rank",b"elec_rank","history",b"history","honor",b"honor","interaction",b"interaction","label",b"label","like_custom",b"like_custom","live_order_info",b"live_order_info","online",b"online","owner_ext",b"owner_ext","pages",b"pages","play_param",b"play_param","player_icon",b"player_icon","rank",b"rank","relate_tab",b"relate_tab","relates",b"relates","req_user",b"req_user","season",b"season","share_subtitle",b"share_subtitle","short_link",b"short_link","special_cell",b"special_cell","staff",b"staff","sticker",b"sticker","t_icon",b"t_icon","tab",b"tab","tag",b"tag","tf_panel_customized",b"tf_panel_customized","ugc_season",b"ugc_season","up_act",b"up_act","up_like_img",b"up_like_img","user_garb",b"user_garb","vip_active",b"vip_active"]) -> None: ...
global___ViewReply = ViewReply

class ViewReq(google.protobuf.message.Message):
    """视频页详情页-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACKID_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    PAGE_VERSION_FIELD_NUMBER: builtins.int
    BIZ_EXTRA_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件avid(av/bv任选其一)"""

    bvid: typing.Text
    """稿件bvid(av/bv任选其一)"""

    trackid: typing.Text
    """AI trackid"""

    ad_extra: typing.Text
    """广告扩展数据"""

    qn: builtins.int
    """清晰度(旧版)"""

    fnver: builtins.int
    """流版本(旧版)"""

    fnval: builtins.int
    """流类型(旧版)"""

    force_host: builtins.int
    """是否强制使用域名(旧版)"""

    fourk: builtins.int
    """是否允许4K(旧版)"""

    spmid: typing.Text
    """当前页面spm"""

    from_spmid: typing.Text
    """上一页面spm"""

    autoplay: builtins.int
    """"""

    @property
    def player_args(self) -> bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """视频秒开参数"""
        pass
    page_version: typing.Text
    """"""

    biz_extra: typing.Text
    """"""

    device_type: builtins.int
    """"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        bvid: typing.Text = ...,
        trackid: typing.Text = ...,
        ad_extra: typing.Text = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.int = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        autoplay: builtins.int = ...,
        player_args: typing.Optional[bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs] = ...,
        page_version: typing.Text = ...,
        biz_extra: typing.Text = ...,
        device_type: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_args",b"player_args"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra",b"ad_extra","aid",b"aid","autoplay",b"autoplay","biz_extra",b"biz_extra","bvid",b"bvid","device_type",b"device_type","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from",b"from","from_spmid",b"from_spmid","page_version",b"page_version","player_args",b"player_args","qn",b"qn","spmid",b"spmid","trackid",b"trackid"]) -> None: ...
global___ViewReq = ViewReq

class Vip(google.protobuf.message.Message):
    """会员信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    DUE_DATE_FIELD_NUMBER: builtins.int
    DUE_REMARK_FIELD_NUMBER: builtins.int
    ACCESS_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_STATUS_WARN_FIELD_NUMBER: builtins.int
    THEME_TYPE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    type: builtins.int
    """会员类型"""

    due_date: builtins.int
    """到期时间"""

    due_remark: typing.Text
    """"""

    access_status: builtins.int
    """"""

    vip_status: builtins.int
    """会员状态"""

    vip_status_warn: typing.Text
    """"""

    theme_type: builtins.int
    """"""

    @property
    def label(self) -> global___VipLabel:
        """"""
        pass
    def __init__(self,
        *,
        type: builtins.int = ...,
        due_date: builtins.int = ...,
        due_remark: typing.Text = ...,
        access_status: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_status_warn: typing.Text = ...,
        theme_type: builtins.int = ...,
        label: typing.Optional[global___VipLabel] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label",b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_status",b"access_status","due_date",b"due_date","due_remark",b"due_remark","label",b"label","theme_type",b"theme_type","type",b"type","vip_status",b"vip_status","vip_status_warn",b"vip_status_warn"]) -> None: ...
global___Vip = Vip

class VipLabel(google.protobuf.message.Message):
    """会员类型标签"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PATH_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    LABEL_THEME_FIELD_NUMBER: builtins.int
    path: typing.Text
    """"""

    text: typing.Text
    """"""

    label_theme: typing.Text
    """"""

    def __init__(self,
        *,
        path: typing.Text = ...,
        text: typing.Text = ...,
        label_theme: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_theme",b"label_theme","path",b"path","text",b"text"]) -> None: ...
global___VipLabel = VipLabel

class subTFPanel(google.protobuf.message.Message):
    """免流子面板定制化配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RIGHT_BTN_IMG_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_FIELD_NUMBER: builtins.int
    RIGHT_BTN_TEXT_COLOR_FIELD_NUMBER: builtins.int
    RIGHT_BTN_LINK_FIELD_NUMBER: builtins.int
    MAIN_LABEL_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    right_btn_img: typing.Text
    """右侧按钮素材"""

    right_btn_text: typing.Text
    """右侧按钮文案"""

    right_btn_text_color: typing.Text
    """右侧按钮字体颜色"""

    right_btn_link: typing.Text
    """右侧按钮跳转链接"""

    main_label: typing.Text
    """中心主文案内容"""

    operator: typing.Text
    """运营商"""

    def __init__(self,
        *,
        right_btn_img: typing.Text = ...,
        right_btn_text: typing.Text = ...,
        right_btn_text_color: typing.Text = ...,
        right_btn_link: typing.Text = ...,
        main_label: typing.Text = ...,
        operator: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_label",b"main_label","operator",b"operator","right_btn_img",b"right_btn_img","right_btn_link",b"right_btn_link","right_btn_text",b"right_btn_text","right_btn_text_color",b"right_btn_text_color"]) -> None: ...
global___subTFPanel = subTFPanel
